
! =================================================================================================================================
! MODULE       : stomate_io
!
! CONTACT      : orchidee-help _at_ listes.ipsl.fr
!
! LICENCE      : IPSL (2006)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>\BRIEF       Module for read and write of restart files for all stomate modules.
!!
!!\n DESCRIPTION : This module contains the subroutines readstart and writerestart. All variables that will be read or written
!!                 are passed as argument to the subroutines. The subroutine readstart is called from stomate_initialize and
!!                 writerestart is called from stomate_finalize.
!!                 Note: Not all variables saved in the start files are absolutely necessary. However, Sechiba's and Stomate's
!!                 PFTs are not necessarily identical, and for that case this information needs to be saved.
!!
!!
!! RECENT CHANGE(S) : None
!!
!! REFERENCE(S)	: None
!!
!! SVN :
!! $HeadURL$
!! $Date$
!! $Revision$
!! \n
!_ ================================================================================================================================
MODULE stomate_io
  USE stomate_data
  USE constantes
  USE constantes_soil
  USE mod_orchidee_para
  USE ioipsl_para
  !-
  IMPLICIT NONE
  !-
  PRIVATE
  PUBLIC readstart, writerestart
  !-
  ! reference temperature (K)
  !-
  REAL(r_std),ALLOCATABLE,DIMENSION(:),SAVE :: trefe
!$OMP THREADPRIVATE(trefe)
  !-
CONTAINS

!! ================================================================================================================================
!! SUBROUTINE   : readstart
!!
!>\BRIEF        Read all variables for stomate from restart file.
!!
!! DESCRIPTION  : Read all variables for stomate from restart file.
!!                Initialize the variables if they were not found in the restart file or if there was no restart file.
!!
!! \n
!_ ================================================================================================================================

  SUBROUTINE readstart &
       & (npts, index, lalo, resolution, temp_air, dt_days, date_loc, &
       &  ind, adapted, regenerate, moiavail_daily, gdd_init_date, litterhum_daily, &
       &  t2m_daily, t2m_min_daily, tsurf_daily, tsoil_daily, &
       &  soilhum_daily, precip_daily, bm_alloc_daily,gi, graz_above_daily, &
       &  gpp_daily, npp_daily, turnover_daily,  &
       &  moiavail_month, moiavail_week, moiavail_growingseason, t2m_longterm, tau_longterm, &
       &  t2m_month, t2m_week, tsoil_month, soilhum_month, &
       &  fireindex, firelitter, &
       &  maxmoiavail_lastyear, maxmoiavail_thisyear, &
       &  minmoiavail_lastyear, minmoiavail_thisyear, &
       &  maxgppweek_lastyear, maxgppweek_thisyear, &
       &  gdd0_lastyear, gdd0_thisyear, precip_lastyear, precip_thisyear, &
       &  bm_alloc_lastyear, bm_alloc_thisyear, &
       &  graz_above_lastyear, graz_above_thisyear, &
       &  harvest_above_lastyear, harvest_above_thisyear, &
       &  gdd_m5_dormance,  gdd_from_growthinit, gdd_midwinter, ncd_dormance, ngd_minus5, &
       &  PFTpresent, npp_longterm, croot_longterm, lm_lastyearmax, lm_thisyearmax, &
       &  maxfpc_lastyear, maxfpc_thisyear, &
       &  turnover_longterm, gpp_week, biomass, resp_maint_part, &
       &  leaf_age, leaf_frac, senescence, when_growthinit, age, &
       &  resp_hetero, resp_maint, resp_growth,resp_excess, co2_fire, co2_to_bm_dgvm, co2_to_bm_radia, &
       &  n_to_bm, veget_lastlight, everywhere, need_adjacent, RIP_time, &
       &  time_hum_min, hum_min_dormance, &
       &  litter,c_litter_manure,m_graz,m_app, distr_eff, biomass_N, biomass_cropC_lit, &
       &   biomass_cropN_lit, sum_biomass_th_grass, &
       &  sum_biomass_th_crop_tot, frac_grass, frac_crop_tot, &
       &  frac_lit, intake, biomass_th_grass, biomass_th_crop_alim, &
       &  biomass_th_crop_lit, biomass_eff_grass, biomass_eff_crop_alim, biomass_eff_crop_lit,  &
       &   cn_crop, cn_grass, &
       &  emis_house_tot, emis_yard, emis_sto_tot , dead_leaves, &
       &  som, lignin_struc, lignin_wood, turnover_time, &
       &  co2_flux, fco2_lu, fco2_wh, fco2_ha, &
       &  prod10,prod100,flux10, flux100, &
       &  convflux, cflux_prod10, cflux_prod100, &
       &  prod10_harvest,prod100_harvest,flux10_harvest, flux100_harvest, &
       &  convflux_harvest, cflux_prod10_harvest, cflux_prod100_harvest, &
       &  convfluxpft, fDeforestToProduct, fLulccResidue, fHarvestToProduct, &
       &  woodharvestpft, bm_to_litter, tree_bm_to_litter, carb_mass_total, nflux_prod,&
       &  nflux_prod_harvest, Tseason, Tseason_length, Tseason_tmp, &
       &  Tmin_spring_time, begin_leaves, onset_date, &
       &  global_years, ok_equilibrium, nbp_accu, nbp_flux, &
       &  MatrixV, VectorU, previous_stock, current_stock, assim_param, &
       &  CN_som_litter_longterm, tau_CN_longterm, KF, k_latosa_adapt, &
       &  rue_longterm, cn_leaf_min_season, nstress_season, soil_n_min, p_O2,bact, &
       &  deepSOM_a, deepSOM_s, deepSOM_p, O2_soil, CH4_soil, O2_snow, CH4_snow, &
       &  heat_Zimov, altmax, depth_organic_soil, fixed_cryoturbation_depth, cn_leaf_init_2D, harvest_above, sugar_load)

    !---------------------------------------------------------------------
    !- read start file
    !---------------------------------------------------------------------
    !-
    ! 0 declarations
    !-
    ! 0.1 input
    !-
    ! Domain size
    INTEGER(i_std),INTENT(in) :: npts
    ! Indices of the points on the map
    INTEGER(i_std),DIMENSION(npts),INTENT(in) :: index
    ! Geogr. coordinates (latitude,longitude) (degrees)
    REAL(r_std),DIMENSION(npts,2),INTENT(in) :: lalo
    ! size in x an y of the grid (m)
    REAL(r_std),DIMENSION(npts,2),INTENT(in) :: resolution
    REAL(r_std),DIMENSION(npts),INTENT(in)   :: temp_air                !! Air temperature from forcing file or coupled model (K)
    REAL(r_std),DIMENSION(npts,nvm), INTENT(in)  :: cn_leaf_init_2D     !! initial leaf C/N ratio
    !-
    ! 0.2 output
    !-
    ! time step of STOMATE in days
    REAL(r_std),INTENT(out) :: dt_days
    ! date_loc (d)
    INTEGER(i_std),INTENT(out) :: date_loc
    ! density of individuals (1/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: ind
    ! Winter too cold? between 0 and 1
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: adapted
    ! Winter sufficiently cold? between 0 and 1
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: regenerate
    ! daily moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: moiavail_daily
    ! date for beginning of gdd count
    REAL(r_std),DIMENSION(npts,2),INTENT(out) :: gdd_init_date
    ! daily litter humidity
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: litterhum_daily
    ! daily 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: t2m_daily
    ! daily minimum 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: t2m_min_daily
    ! daily surface temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: tsurf_daily
    ! daily soil temperatures (K)
    REAL(r_std),DIMENSION(npts,nslm),INTENT(out) :: tsoil_daily
    ! daily soil humidity
    REAL(r_std),DIMENSION(npts,nslm),INTENT(out) :: soilhum_daily
    ! daily precipitations (mm/day) (for phenology)
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: precip_daily
    ! daily gross primary productivity (gC/m**2/day)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: gpp_daily
    ! daily net primary productivity (gC/m**2/day)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: npp_daily
    ! daily net primary productivity (gC/m**2/day)
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(out) :: bm_alloc_daily
    ! grazing intensity
    REAL(r_std),DIMENSION(npts),INTENT(out) :: gi
    ! daily biomass grazed
    REAL(r_std),DIMENSION(npts,nelements),INTENT(out) :: graz_above_daily
    ! daily turnover rates (gC/m**2/day)
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(out) :: turnover_daily
    ! "monthly" moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: moiavail_month
    ! "weekly" moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: moiavail_week
    ! mean growing season moisture availability (used for allocation response)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: moiavail_growingseason
    ! "long term" 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: t2m_longterm
    ! "tau_longterm"
    REAL(r_std), INTENT(out)        :: tau_longterm
    ! "monthly" 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: t2m_month
    ! "seasonal" 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: Tseason
    ! temporary variable to calculate Tseason
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: Tseason_length
    ! temporary variable to calculate Tseason
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: Tseason_tmp
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out)  :: Tmin_spring_time
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out)  :: onset_date
    LOGICAL,DIMENSION(npts,nvm),INTENT(out)      :: begin_leaves

    ! "weekly" 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: t2m_week
    ! "monthly" soil temperatures (K)
    REAL(r_std),DIMENSION(npts,nslm),INTENT(out) :: tsoil_month
    ! "monthly" soil humidity
    REAL(r_std),DIMENSION(npts,nslm),INTENT(out) :: soilhum_month
    ! Probability of fire
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: fireindex
    ! Longer term total litter above the ground, gC/m**2 of ground
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: firelitter
    ! last year's maximum moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: maxmoiavail_lastyear
    ! this year's maximum moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: maxmoiavail_thisyear
    ! last year's minimum moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: minmoiavail_lastyear
    ! this year's minimum moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: minmoiavail_thisyear
    ! last year's maximum weekly GPP
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: maxgppweek_lastyear
    ! this year's maximum weekly GPP
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: maxgppweek_thisyear
    ! last year's annual GDD0
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: gdd0_lastyear
    ! this year's annual GDD0
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: gdd0_thisyear
    ! last year's annual precipitation (mm/year)
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: precip_lastyear
    ! this year's annual precipitation (mm/year)
    REAL(r_std),DIMENSION(npts),INTENT(out)      :: precip_thisyear
    ! last year's annual NPP
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(out)      :: bm_alloc_lastyear
    ! this year's annual NPP
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(out)      :: bm_alloc_thisyear
    ! last year's annual biomass grazed
    REAL(r_std),DIMENSION(npts,nelements),INTENT(out)      :: graz_above_lastyear
    ! this year's annual biomass grazed
    REAL(r_std),DIMENSION(npts,nelements),INTENT(out)      :: graz_above_thisyear
    ! last year's annual biomass harvested
    REAL(r_std),DIMENSION(npts,nelements),INTENT(out)      :: harvest_above_lastyear
    ! this year's annual biomass harvested
    REAL(r_std),DIMENSION(npts,nelements),INTENT(out)      :: harvest_above_thisyear
    ! growing degree days, threshold -5 deg C (for phenology)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: gdd_m5_dormance
    ! growing degree days, from begin of season
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: gdd_from_growthinit
    ! growing degree days since midwinter (for phenology)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: gdd_midwinter
    ! number of chilling days since leaves were lost (for phenology)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: ncd_dormance
    ! number of growing days, threshold -5 deg C (for phenology)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: ngd_minus5
    ! PFT exists (equivalent to fpc_max > 0 for natural PFTs)
    LOGICAL,DIMENSION(npts,nvm),INTENT(out)    :: PFTpresent
    ! "long term" net primary productivity (gC/m**2/year)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: npp_longterm
    ! "long term" root carbon mass (gC/m**2/year)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: croot_longterm
    ! last year's maximum leaf mass, for each PFT (gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: lm_lastyearmax
    ! this year's maximum leaf mass, for each PFT (gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: lm_thisyearmax
    ! last year's maximum fpc for each natural PFT, on ground
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: maxfpc_lastyear
    ! this year's maximum fpc for each PFT,
    ! on *total* ground (see stomate_season)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: maxfpc_thisyear
    ! "long term" turnover rate (gC/m**2/year)
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(out) :: turnover_longterm
    ! "weekly" GPP (gC/day/(m**2 covered)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: gpp_week
    ! biomass (gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(out) :: biomass
    ! maintenance resp (gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm,nparts),INTENT(out) :: resp_maint_part
    ! leaf age (days)
    REAL(r_std),DIMENSION(npts,nvm,nleafages),INTENT(out) :: leaf_age
    ! fraction of leaves in leaf age class
    REAL(r_std),DIMENSION(npts,nvm,nleafages),INTENT(out) :: leaf_frac
    ! is the plant senescent ?
    !(only for deciduous trees - carbohydrate reserve)
    LOGICAL,DIMENSION(npts,nvm),INTENT(out) :: senescence
    ! how many days ago was the beginning of the growing season
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: when_growthinit
    ! mean age (years)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: age
    ! heterotrophic respiration (gC/day/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: resp_hetero
    ! maintenance respiration (gC/day/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: resp_maint
    ! growth respiration (gC/day/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: resp_growth
    ! excess respiration (gC/day/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: resp_excess
    ! carbon emitted into the atmosphere by fire (living and dead biomass)
    ! (in gC/m**2/time step)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: co2_fire
    ! biomass uptaken (gC/(m**2 of total ground)/day)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: co2_to_bm_dgvm
    ! biomass uptaken (gN/(m**2 of total ground)/day)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: n_to_bm
    ! biomass uptaken (gC/(m**2 of total ground)/dt_sechiba)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: co2_to_bm_radia
    ! vegetation fractions (on ground) after last light competition
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: veget_lastlight
    ! is the PFT everywhere in the grid box or very localized
    ! (after its introduction)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: everywhere
    ! in order for this PFT to be introduced,
    ! does it have to be present in an adjacent grid box?
    LOGICAL,DIMENSION(npts,nvm),INTENT(out) :: need_adjacent
    ! How much time ago was the PFT eliminated for the last time (y)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: RIP_time
    ! time elapsed since strongest moisture availability (d)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: time_hum_min
    ! minimum moisture during dormance
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: hum_min_dormance
    ! fraction of litter above the ground belonging to different PFTs
    ! separated for natural and agricultural PFTs.
    REAL(r_std),DIMENSION(npts,nlitt,nvm,nlevs,nelements),INTENT(out):: litter
    ! dead leaves on ground, per PFT, metabolic and structural,
    ! in gC/(m**2 of ground)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out)::c_litter_manure
    REAL(r_std),DIMENSION(npts,nlm,forms),INTENT(out)::m_graz
    REAL(r_std),DIMENSION(npts,nlm,forms),INTENT(out)::m_app
    REAL(r_std), DIMENSION(npts,nlm), INTENT(out):: distr_eff           !! Livestock distribution map reajusted according to actual biomass grazed
                                                                                        !! (Heads/km2/yr)
    REAL(r_std), DIMENSION(npts,nlm), INTENT(out)            :: biomass_N        !! Biomass ingested by each animal (kg N/m2/yr)
    REAL(r_std), DIMENSION(npts,nlm), INTENT(out)            :: biomass_cropC_lit !! Biomass used as litter by each animal (kg C/m2/yr)
    REAL(r_std), DIMENSION(npts,nlm), INTENT(out)            :: biomass_cropN_lit !! Biomass used as litter by each animal (kg N/m2/yr)

    REAL(r_std)               , INTENT(out)          :: cn_crop            ! CN of the crop biomass
    REAL(r_std), DIMENSION(npts), INTENT(out)         :: cn_grass            ! CN of the grass biomass
    REAL(r_std), DIMENSION(npts), INTENT(out)          :: sum_biomass_th_grass !! Sum of the estimated grass biomass ingested by all the animals
                                                                                !! kg C/m2/yr
    REAL(r_std), DIMENSION(npts), INTENT(out)          :: sum_biomass_th_crop_tot !! Sum of the estimated crop biomass ingested by all the animals
                                                                                !! kg C/m2/yr
    REAL(r_std),DIMENSION(npts,nlm), INTENT(out)        :: frac_grass         !! Proportion of importance of each animal in grass biomass
    REAL(r_std),DIMENSION(npts,nlm), INTENT(out)        :: frac_crop_tot      !! Proportion of importance of each animal in crop biomass
    REAL(r_std),DIMENSION(npts,nlm), INTENT(out)        :: frac_lit           !! Proportion of importance of each animal in crop biomass used as litter
    REAL(r_std), DIMENSION(npts,nlm), INTENT(out)       :: intake           !! Intake required for each animal (kg C/year/ani)
    REAL(r_std), DIMENSION(npts,nlm), INTENT(out)        :: biomass_th_grass  !! Carbon biomass from grass estimated for each animal
                                                                              !! kg C/m2/yr
     REAL(r_std), DIMENSION(npts,nlm), INTENT(out)        :: biomass_th_crop_alim !! Feed crop biomass required for each animal (kg C/m2/yr)
     REAL(r_std), DIMENSION(npts,nlm), INTENT(out)        :: biomass_th_crop_lit !! Theoretical crop biomass used as litter by each animal (kg C/m2/yr)
     REAL(r_std),DIMENSION(npts,nlm),INTENT(out)                   :: biomass_eff_grass    !! Actual grass biomass used by each animal (kg C/m2/yr)
     REAL(r_std),DIMENSION(npts,nlm),INTENT(out)      :: biomass_eff_crop_alim ! Actual crop biomass ingested by each animal (kg C/m2/yr)
     REAL(r_std),DIMENSION(npts,nlm),INTENT(out)      :: biomass_eff_crop_lit  !! Actual crop biomass used as litter by each animal (kg C/m2/yr)
    REAL(r_std), DIMENSION(npts,nlm), INTENT(out):: emis_house_tot     !! NH3 Emissions from manure at housing (liquid + solid)
                                                                                  !! for each animal (kg TAN/m2/yr)
    REAL(r_std), DIMENSION(npts,nlm), INTENT(out):: emis_yard         !! NH3 Emissions from manure at yard (liquid + solid)
                                                                                  !! for each animal (kg TAN/m2/yr)
    REAL(r_std), DIMENSION(npts,nlm), INTENT(out):: emis_sto_tot      !! NH3 Emissions from manure during storage (liquid + solid)
                                                                                  !! for each animal (kg TAN/m2/yr)
    REAL(r_std),DIMENSION(npts,nvm,nlitt),INTENT(out) :: dead_leaves
    ! Soil Organic Matter pool: active, slow, or passive, (gC (or N)/m**2)
    REAL(r_std),DIMENSION(npts,ncarb,nvm,nelements),INTENT(out) :: som
    ! ratio Lignine/Carbon in structural litter, above and below ground,(gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm,nlevs),INTENT(out) :: lignin_struc
    ! ratio Lignine/Carbon in woody litter, above and below ground,(gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm,nlevs),INTENT(out) :: lignin_wood
    REAL(r_std),DIMENSION(npts,nvm),INTENT(out) :: turnover_time

    ! For Spinup matrix resolution
    INTEGER(i_std), INTENT(out) :: global_years
    LOGICAL, DIMENSION(npts), INTENT(out) :: ok_equilibrium
    REAL(r_std), DIMENSION(npts), INTENT(out) :: nbp_accu  !! Accumulated Net Biospheric Production over the year
    REAL(r_std), DIMENSION(npts), INTENT(out) :: nbp_flux  !! Net Biospheric Production over the year
    !-
    REAL(r_std), DIMENSION(npts,nvm,nbpools,nbpools), INTENT(out) :: MatrixV
    REAL(r_std), DIMENSION(npts,nvm,nbpools), INTENT(out) :: VectorU
    REAL(r_std), DIMENSION(npts,nvm,nbpools), INTENT(out) :: previous_stock
    REAL(r_std), DIMENSION(npts,nvm,nbpools), INTENT(out) :: current_stock
    REAL(r_std), DIMENSION(npts,nvm,nbpools), INTENT(out) :: CN_som_litter_longterm !! Longterm CN ratio of litter and som pools (gC/gN)
    REAL(r_std), INTENT(out)                              :: tau_CN_longterm  !! Counter used for calculating the longterm CN ratio of SOM and litter pools (seconds)
    REAL(r_std), DIMENSION(npts,nvm,npco2),   INTENT(out) :: assim_param

    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)           :: KF             !! Scaling factor to convert sapwood mass
                                                                              !! into leaf mass (m)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)           :: k_latosa_adapt !! Leaf to sapwood area adapted for water
                                                                              !! stress. Adaptation takes place at the
                                                                              !! end of the year (m)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                       :: rue_longterm            !! longterm radiation use efficiency
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                       :: cn_leaf_min_season          !! Seasonal min CN ratio of leaves
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                       :: nstress_season          !! N-related seasonal stress (used for allocation)

    REAL(r_std), DIMENSION(npts,nvm,nnspec), INTENT(out)                :: soil_n_min              !! mineral nitrogen in the soil (gN/m**2)
                                                                                                   !! (first index=npts, second index=nvm, third index=nnspec)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                       :: p_O2                    !! partial pressure of oxigen in the soil (hPa)
                                                                                                   !! (first index=npts, second index=nvm)

    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                       :: bact                    !! denitrifier biomass (gC/m**2)
                                                                                                   !! (first index=npts, second index=nvm)

    !-
    REAL(r_std), DIMENSION(npts,ngrnd,nvm,nelements),INTENT(out) :: deepSOM_a
    REAL(r_std), DIMENSION(npts,ngrnd,nvm,nelements),INTENT(out) :: deepSOM_s
    REAL(r_std), DIMENSION(npts,ngrnd,nvm,nelements),INTENT(out) :: deepSOM_p
    REAL(r_std), DIMENSION(npts,ngrnd,nvm),INTENT(out)           :: O2_soil
    REAL(r_std), DIMENSION(npts,ngrnd,nvm),INTENT(out)           :: CH4_soil
    REAL(r_std), DIMENSION(npts,nsnow,nvm),INTENT(out)           :: O2_snow
    REAL(r_std), DIMENSION(npts,nsnow,nvm),INTENT(out)           :: CH4_snow
    REAL(r_std), DIMENSION(npts,ngrnd,nvm), INTENT(out)          :: heat_Zimov !! heating associated with decomposition [W/m**3 soil]
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                :: altmax     !! Active layer thickness (m)
    REAL(r_std), DIMENSION(npts),INTENT(out)                     :: depth_organic_soil !! Depth at which there is still organic matter (m)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                :: fixed_cryoturbation_depth !! Depth to hold cryoturbation to for fixed runs
    REAL(r_std), DIMENSION(npts,nelements), INTENT(out)          :: harvest_above
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                :: sugar_load                !! Relative sugar loading of the labile pool (unitless)
    ! 0.4 local
    !-
    ! date, real
    REAL(r_std) :: date_real
    ! PFT exists (equivalent to fpc_max > 0 for natural PFTs), real
    REAL(r_std),DIMENSION(npts,nvm) :: PFTpresent_real
    ! is the plant senescent ?
    ! (only for deciduous trees - carbohydrate reserve), real
    REAL(r_std),DIMENSION(npts,nvm) :: senescence_real
    REAL(r_std),DIMENSION(npts,nvm) :: begin_leaves_real
    ! in order for this PFT to be introduced,
    ! does it have to be present in an adjacent grid box? - real
    REAL(r_std),DIMENSION(npts,nvm) :: need_adjacent_real
    ! To store variables names for I/O
    CHARACTER(LEN=80) :: var_name
    ! string suffix indicating an index
    CHARACTER(LEN=10) :: part_str
    ! string suffix indicating litter type
    CHARACTER(LEN=4),DIMENSION(nlitt) :: litter_str
    ! string suffix indicating level
    CHARACTER(LEN=2),DIMENSION(nlevs) :: level_str
    ! temporary storage
    REAL(r_std),DIMENSION(1) :: xtmp
    ! index
    INTEGER(i_std) :: j,k,l,m
    ! reference temperature (K)

    CHARACTER(LEN=2),DIMENSION(nelements) :: element_str   !! string suffix indicating element
    REAL(r_std), DIMENSION(1) :: temp_global_years
    CHARACTER(LEN=6), DIMENSION(nbpools) :: pools_str
    REAL(r_std), DIMENSION(npts) :: ok_equilibrium_real

    ! land cover change variables
    ! products remaining in the 10/100 year-turnover pool after the annual release for each compartment
    ! (10 or 100 + 1 : input from year of land cover change)
    REAL(r_std),DIMENSION(npts, nvm),INTENT(out)                           :: co2_flux
    REAL(r_std),DIMENSION(npts),INTENT(out)                                :: fco2_lu
    REAL(r_std),DIMENSION(npts),INTENT(out)                                :: fco2_wh
    REAL(r_std),DIMENSION(npts),INTENT(out)                                :: fco2_ha
    REAL(r_std),DIMENSION(npts,0:10),INTENT(out)                           :: prod10
    REAL(r_std),DIMENSION(npts,0:100),INTENT(out)                          :: prod100
    ! annual release from the 10/100 year-turnover pool compartments
    REAL(r_std),DIMENSION(npts,10),INTENT(out)                           :: flux10
    REAL(r_std),DIMENSION(npts,100),INTENT(out)                          :: flux100
    REAL(r_std), DIMENSION(npts), INTENT(out)                            :: convflux
    REAL(r_std), DIMENSION(npts), INTENT(out)                            :: cflux_prod10
    REAL(r_std), DIMENSION(npts), INTENT(out)                            :: cflux_prod100
    ! wood harvest variables
    ! products remaining in the 10/100 year-turnover pool after the annual release for each compartment
    ! (10 or 100 + 1 : input from year of land cover change)
    REAL(r_std),DIMENSION(npts,0:10),INTENT(out)                           :: prod10_harvest
    REAL(r_std),DIMENSION(npts,0:100),INTENT(out)                          :: prod100_harvest
    ! annual release from the 10/100 year-turnover pool compartments
    REAL(r_std),DIMENSION(npts,10),INTENT(out)                           :: flux10_harvest
    REAL(r_std),DIMENSION(npts,100),INTENT(out)                          :: flux100_harvest
    REAL(r_std), DIMENSION(npts), INTENT(out)                            :: convflux_harvest
    REAL(r_std), DIMENSION(npts), INTENT(out)                            :: cflux_prod10_harvest
    REAL(r_std), DIMENSION(npts), INTENT(out)                            :: cflux_prod100_harvest
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                        :: convfluxpft
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                        :: fDeforestToProduct
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                        :: fLulccResidue
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                        :: fHarvestToProduct
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                        :: woodharvestpft
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(out)         :: bm_to_litter
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(out)         :: tree_bm_to_litter
    REAL(r_std),DIMENSION(npts),INTENT(out)                              :: carb_mass_total
    REAL(r_std), DIMENSION(npts), INTENT(out)                            :: nflux_prod
    REAL(r_std), DIMENSION(npts), INTENT(out)                            :: nflux_prod_harvest
    REAL(r_std),DIMENSION(npts,nvm)                                      :: vcmax_tmp

    ! Permafrost carbon processes
    LOGICAL :: read_input_deepC_a
    LOGICAL :: read_input_deepC_s
    LOGICAL :: read_input_deepC_p
    LOGICAL :: read_input_thawed_humidity
    LOGICAL :: read_input_depth_organic_soil

    !---------------------------------------------------------------------
    IF (printlev >= 3) WRITE(numout,*) 'Entering readstart'
    !-
    ! 1 string definitions
    !-
    DO l=1,nlitt
       IF     (l == imetabolic) THEN
          litter_str(l) = 'met'
       ELSEIF (l == istructural) THEN
          litter_str(l) = 'str'
       ELSEIF (l == iwoody) THEN
          litter_str(l) = 'wood'
       ELSE
          CALL ipslerr_p(3,'stomate_io readstart', 'Define litter_str','','')
       ENDIF
    ENDDO
    !-
    DO l=1,nlevs
       IF     (l == iabove) THEN
          level_str(l) = 'ab'
       ELSEIF (l == ibelow) THEN
          level_str(l) = 'be'
       ELSE
          CALL ipslerr_p(3,'stomate_io readstart','Define level_str','','')
       ENDIF
    ENDDO

    pools_str(1:nbpools) =(/'str_ab ','str_be ','met_ab ','met_be ','wood_ab','wood_be',&
         & 'actif  ','slow   ','passif ','surface'/)
    !-
    DO l=1,nelements
       IF     (l == icarbon) THEN
          element_str(l) = ''
       ELSEIF (l == initrogen) THEN
          element_str(l) = '_n'
       ELSE
          CALL ipslerr_p(3,'stomate_io readstart','Define element_str','','')
       ENDIF
    ENDDO
    !-
    ! 2 run control
    !-
    ! 2.2 time step of STOMATE in days
    !-    If the variable is not in the restart file, then un will be used as default value
    CALL restget_p(rest_id_stomate, 'dt_days', itime, .TRUE., un, dt_days)
    !-
    ! 2.3 date
    !-    If the variable is not in the restart file, then zero will be used as default value
    CALL restget_p (rest_id_stomate, 'date', itime, .TRUE., zero, date_real)
    date_loc = NINT(date_real)
    !-
    ! 3 daily meteorological variables
    !-
    moiavail_daily(:,:) = val_exp
    var_name = 'moiavail_daily'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., moiavail_daily, 'gather', nbp_glo, index_g)
    IF (ALL(moiavail_daily(:,:) == val_exp)) moiavail_daily(:,:) = zero
    !-
    gdd_init_date(:,:) = val_exp
    var_name = 'gdd_init_date'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 2 , 1, itime, &
         &              .TRUE., gdd_init_date, 'gather', nbp_glo, index_g)
    ! Keep val_exp as initial value for gdd_init_date(:,2)
    IF (ALL(gdd_init_date(:,1) == val_exp)) gdd_init_date(:,1) = 365.

    !-
    litterhum_daily(:) = val_exp
    var_name = 'litterhum_daily'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &              .TRUE., litterhum_daily, 'gather', nbp_glo, index_g)
    IF (ALL(litterhum_daily(:) == val_exp)) litterhum_daily(:) = zero
    !-
    t2m_daily(:) = val_exp
    var_name = 't2m_daily'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &                .TRUE., t2m_daily, 'gather', nbp_glo, index_g)
    IF (ALL(t2m_daily(:) == val_exp)) t2m_daily(:) = zero
    !-
    t2m_min_daily(:) = val_exp
    var_name = 't2m_min_daily'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &                .TRUE., t2m_min_daily, 'gather', nbp_glo, index_g)
    IF (ALL(t2m_min_daily(:) == val_exp)) t2m_min_daily(:) = large_value
    !-
    tsurf_daily(:) = val_exp
    var_name = 'tsurf_daily'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &                .TRUE., tsurf_daily, 'gather', nbp_glo, index_g)
    ! The initial value is set to the current temperature at 2m
    IF (ALL(tsurf_daily(:) == val_exp)) tsurf_daily(:) = temp_air(:)
    !-
    tsoil_daily(:,:) = val_exp
    var_name = 'tsoil_daily'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo,   nslm, 1, itime, &
         &                .TRUE., tsoil_daily, 'gather', nbp_glo, index_g)
    IF (ALL(tsoil_daily(:,:) == val_exp)) tsoil_daily(:,:) = zero
    !-
    soilhum_daily(:,:) = val_exp
    var_name = 'soilhum_daily'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo,   nslm, 1, itime, &
         &                .TRUE., soilhum_daily, 'gather', nbp_glo, index_g)
    IF (ALL(soilhum_daily(:,:) == val_exp)) soilhum_daily(:,:) = zero
    !-
    precip_daily(:) = val_exp
    var_name = 'precip_daily'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &                .TRUE., precip_daily, 'gather', nbp_glo, index_g)
    IF (ALL(precip_daily(:) == val_exp)) precip_daily(:) = zero
    !-
    ! 4 productivities
    !-
    gpp_daily(:,:) = val_exp
    var_name = 'gpp_daily'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., gpp_daily, 'gather', nbp_glo, index_g)
    IF (ALL(gpp_daily(:,:) == val_exp)) gpp_daily(:,:) = zero
    !-
    npp_daily(:,:) = val_exp
    var_name = 'npp_daily'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., npp_daily, 'gather', nbp_glo, index_g)
    IF (ALL(npp_daily(:,:) == val_exp)) npp_daily(:,:) = zero
    !-
    turnover_daily(:,:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'turnover_daily', nbp_glo, nvm, nparts, nelements, itime, &
         &                .TRUE., turnover_daily, 'gather', nbp_glo, index_g)
    IF (ALL(turnover_daily == val_exp)) turnover_daily = zero

    bm_alloc_daily(:,:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'bm_alloc_daily', nbp_glo, nvm, nparts, nelements, itime, &
         &                .TRUE., bm_alloc_daily, 'gather', nbp_glo, index_g)
    IF (ALL(bm_alloc_daily == val_exp)) bm_alloc_daily = zero

    gi(:) = val_exp
    CALL restget_p (rest_id_stomate, 'gi', nbp_glo,1,1,itime, &
         &                .TRUE., gi, 'gather', nbp_glo, index_g)
    IF (ALL(gi == val_exp)) gi = zero

    graz_above_daily(:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'graz_above_daily', nbp_glo,nelements,1, itime, &
         &                .TRUE., graz_above_daily, 'gather', nbp_glo, index_g)
    IF (ALL(graz_above_daily == val_exp)) graz_above_daily = zero
    !-
    ! 5 monthly meteorological variables
    !-
    moiavail_month(:,:) = val_exp
    var_name = 'moiavail_month'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., moiavail_month, 'gather', nbp_glo, index_g)
    IF (ALL(moiavail_month(:,:) == val_exp)) moiavail_month(:,:) = zero
    !-
    moiavail_week(:,:) = val_exp
    var_name = 'moiavail_week'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., moiavail_week, 'gather', nbp_glo, index_g)
    IF (ALL(moiavail_week(:,:) == val_exp)) moiavail_week(:,:) = zero

    moiavail_growingseason(:,:) = val_exp
    var_name = 'moiavail_grow'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., moiavail_growingseason, 'gather', nbp_glo, index_g)
    IF (ALL(moiavail_growingseason(:,:) == val_exp)) moiavail_growingseason(:,:) = un


    !
    ! Longterm temperature at 2m
    !
    var_name = 't2m_longterm'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &              .TRUE., t2m_longterm, 'gather', nbp_glo, index_g)

    IF (ALL(t2m_longterm(:) == val_exp)) THEN
       ! t2m_longterm is not in restart file
       ! The initial value for the reference temperature is set to the current temperature
       t2m_longterm(:)=temp_air(:)
       ! Set the counter to 2 time steps
       tau_longterm=2
    ELSE
       ! t2m_longterm was in the restart file
       ! Now read tau_longterm
       ! tau_longterm is a scalar, therefor only master process read this value
       CALL restget_p (rest_id_stomate, 'tau_longterm', itime, .TRUE., val_exp, tau_longterm)
       IF (tau_longterm == val_exp) THEN
             ! tau_longterm is not found in restart file.
             ! This is not normal as t2m_longterm was in restart file. Write a warning and initialize it to tau_longterm_max
          CALL ipslerr(2, 'stomate_io readstart','tau_longterm was not in restart file',&
               'But t2m_longterm was in restart file','')
          tau_longterm = tau_longterm_max
       END IF

    END IF
    !-
    t2m_month(:) = val_exp
    var_name = 't2m_month'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &              .TRUE., t2m_month, 'gather', nbp_glo, index_g)
    IF (ALL(t2m_month(:) == val_exp)) t2m_month(:) = temp_air(:)

    CALL restget_p (rest_id_stomate, 'Tseason', nbp_glo, 1     , 1, itime, &
         .TRUE., Tseason, 'gather', nbp_glo, index_g)
    IF (ALL(Tseason(:) == val_exp)) Tseason(:) = temp_air(:)

    CALL restget_p (rest_id_stomate,'Tseason_length', nbp_glo, 1     , 1, itime, &
         .TRUE., Tseason_length, 'gather', nbp_glo, index_g)
    IF (ALL(Tseason_length(:) == val_exp)) Tseason_length(:) = zero

    CALL restget_p (rest_id_stomate, 'Tseason_tmp', nbp_glo, 1     , 1, itime, &
         .TRUE., Tseason_tmp, 'gather', nbp_glo, index_g)
    IF (ALL(Tseason_tmp(:) == val_exp)) Tseason_tmp(:) = zero

    CALL restget_p (rest_id_stomate, 'Tmin_spring_time', nbp_glo, nvm, 1, itime, &
         .TRUE., Tmin_spring_time, 'gather', nbp_glo, index_g)
    IF (ALL(Tmin_spring_time(:,:) == val_exp)) Tmin_spring_time(:,:) = zero

    CALL restget_p (rest_id_stomate, 'onset_date', nbp_glo, nvm  , 1, itime, &
         .TRUE., onset_date(:,:), 'gather', nbp_glo, index_g)
    IF (ALL(onset_date(:,:) == val_exp)) onset_date(:,:) = zero

    t2m_week(:) = val_exp
    var_name = 't2m_week'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &              .TRUE., t2m_week, 'gather', nbp_glo, index_g)
    ! The initial value is set to the current temperature
    IF (ALL(t2m_week(:) == val_exp)) t2m_week(:) = temp_air(:)

    tsoil_month(:,:) = val_exp
    var_name = 'tsoil_month'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo,   nslm, 1, itime, &
         &              .TRUE., tsoil_month, 'gather', nbp_glo, index_g)

    ! The initial value is set to the current temperature
    IF (ALL(tsoil_month(:,:) == val_exp)) THEN
       DO l=1,nslm
          tsoil_month(:,l) = temp_air(:)
       ENDDO
    ENDIF
    !-
    soilhum_month(:,:) = val_exp
    var_name = 'soilhum_month'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo,   nslm, 1, itime, &
         &              .TRUE., soilhum_month, 'gather', nbp_glo, index_g)
    IF (ALL(soilhum_month(:,:) == val_exp)) soilhum_month(:,:) = zero
    !-
    ! 6 fire probability
    !-
    fireindex(:,:) = val_exp
    var_name = 'fireindex'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &              .TRUE., fireindex, 'gather', nbp_glo, index_g)
    IF (ALL(fireindex(:,:) == val_exp)) fireindex(:,:) = zero
    !-
    firelitter(:,:) = val_exp
    var_name = 'firelitter'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &              .TRUE., firelitter, 'gather', nbp_glo, index_g)
    IF (ALL(firelitter(:,:) == val_exp)) firelitter(:,:) = zero
    !-
    ! 7 maximum and minimum moisture availabilities for tropic phenology
    !-
    maxmoiavail_lastyear(:,:) = val_exp
    var_name = 'maxmoistr_last'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., maxmoiavail_lastyear, 'gather', nbp_glo, index_g)
    IF (ALL(maxmoiavail_lastyear(:,:) == val_exp)) &
         &     maxmoiavail_lastyear(:,:) = zero
    !-
    maxmoiavail_thisyear(:,:) = val_exp
    var_name = 'maxmoistr_this'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., maxmoiavail_thisyear, 'gather', nbp_glo, index_g)
    IF (ALL(maxmoiavail_thisyear(:,:) == val_exp)) &
         &     maxmoiavail_thisyear(:,:) = zero
    !-
    minmoiavail_lastyear(:,:) = val_exp
    var_name = 'minmoistr_last'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., minmoiavail_lastyear, 'gather', nbp_glo, index_g)
    IF (ALL(minmoiavail_lastyear(:,:) == val_exp)) &
         &     minmoiavail_lastyear(:,:) = un
    !-
    minmoiavail_thisyear(:,:) = val_exp
    var_name = 'minmoistr_this'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., minmoiavail_thisyear, 'gather', nbp_glo, index_g)
    IF (ALL( minmoiavail_thisyear(:,:) == val_exp)) &
         &     minmoiavail_thisyear(:,:) = un
    !-
    ! 8 maximum "weekly" GPP
    !-
    maxgppweek_lastyear(:,:) = val_exp
    var_name = 'maxgppweek_lastyear'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., maxgppweek_lastyear, 'gather', nbp_glo, index_g)
    IF (ALL(maxgppweek_lastyear(:,:) == val_exp)) &
         &     maxgppweek_lastyear(:,:) = zero
    !-
    maxgppweek_thisyear(:,:) = val_exp
    var_name = 'maxgppweek_thisyear'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., maxgppweek_thisyear, 'gather', nbp_glo, index_g)
    IF (ALL(maxgppweek_thisyear(:,:) == val_exp)) &
         &     maxgppweek_thisyear(:,:) = zero
    !-
    ! 9 annual GDD0
    !-
    gdd0_thisyear(:) = val_exp
    var_name = 'gdd0_thisyear'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &              .TRUE., gdd0_thisyear, 'gather', nbp_glo, index_g)
    IF (ALL(gdd0_thisyear(:) == val_exp)) gdd0_thisyear(:) = zero
    !-
    gdd0_lastyear(:) = val_exp
    var_name = 'gdd0_lastyear'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &              .TRUE., gdd0_lastyear, 'gather', nbp_glo, index_g)
    IF (ALL(gdd0_lastyear(:) == val_exp)) gdd0_lastyear(:) = gdd_crit_estab
    !-
    ! 10 annual precipitation
    !-
    precip_thisyear(:) = val_exp
    var_name = 'precip_thisyear'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &              .TRUE., precip_thisyear, 'gather', nbp_glo, index_g)
    IF (ALL(precip_thisyear(:) == val_exp)) precip_thisyear(:) = zero
    !-
    precip_lastyear(:) = val_exp
    var_name = 'precip_lastyear'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &              .TRUE., precip_lastyear, 'gather', nbp_glo, index_g)
    IF (ALL(precip_lastyear(:) == val_exp)) &
         &     precip_lastyear(:) = precip_crit

   !-
   ! 11 annual npp
   !-
   bm_alloc_thisyear(:,:,:,:) = val_exp
   var_name = 'bm_alloc_thisyear'
   CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , nparts,nelements, itime, &
        &              .TRUE., bm_alloc_thisyear(:,:,:,:), 'gather', nbp_glo, index_g)
   IF (ALL(bm_alloc_thisyear(:,:,:,:) == val_exp)) bm_alloc_thisyear(:,:,:,:) = zero
   !-
   bm_alloc_lastyear(:,:,:,:) = val_exp
   var_name = 'bm_alloc_lastyear'
   CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  ,nparts,nelements, itime, &
        &              .TRUE., bm_alloc_lastyear(:,:,:,:), 'gather', nbp_glo, index_g)
   IF (ALL(bm_alloc_lastyear(:,:,:,:) == val_exp)) &
        &     bm_alloc_lastyear(:,:,:,:) = zero
    !-
    ! 11 bis annual biomass grazed by ruminants
    !-

    graz_above_thisyear(:,:) = val_exp
    var_name = 'graz_above_thisyear'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo,  nelements , 1, itime, &
         &              .TRUE., graz_above_thisyear(:,:), 'gather', nbp_glo, index_g)
    IF (ALL(graz_above_thisyear(:,:) == val_exp)) graz_above_thisyear(:,:) = zero
    !-
    graz_above_lastyear(:,:) = val_exp
    var_name = 'graz_above_lastyear'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nelements  , 1, itime, &
         &              .TRUE., graz_above_lastyear(:,:), 'gather', nbp_glo, index_g)
    IF (ALL(graz_above_lastyear(:,:) == val_exp)) &
         &     graz_above_lastyear(:,:) = zero

     !-
     ! 11 ter annual biomass harvested for livestock
     !-

     harvest_above_thisyear(:,:) = val_exp
     var_name = 'harvest_above_thisyear'
     CALL restget_p (rest_id_stomate, var_name, nbp_glo, nelements  , 1, itime, &
          &              .TRUE., harvest_above_thisyear(:,:), 'gather', nbp_glo, index_g)
     IF (ALL(harvest_above_thisyear(:,:) == val_exp)) harvest_above_thisyear(:,:) = zero
     !-
     harvest_above_lastyear(:,:) = val_exp
     var_name = 'harvest_above_lastyear'
     CALL restget_p (rest_id_stomate, var_name, nbp_glo, nelements  , 1, itime, &
          &              .TRUE., harvest_above_lastyear(:,:), 'gather', nbp_glo, index_g)
     IF (ALL(harvest_above_lastyear(:,:) == val_exp)) &
          &     harvest_above_lastyear(:,:) = zero
     !-

    ! 12 derived "biometeorological" variables
    !-
    gdd_m5_dormance(:,:) = val_exp
    var_name = 'gdd_m5_dormance'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., gdd_m5_dormance, 'gather', nbp_glo, index_g)
    IF (ALL(gdd_m5_dormance(:,:) == val_exp)) &
         &     gdd_m5_dormance(:,:) = undef
    !-
    gdd_from_growthinit(:,:) = val_exp
    var_name = 'gdd_from_growthinit'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., gdd_from_growthinit, 'gather', nbp_glo, index_g)
    IF (ALL(gdd_from_growthinit(:,:) == val_exp)) &
         &     gdd_from_growthinit(:,:) = zero
    !-
    gdd_midwinter(:,:) = val_exp
    var_name = 'gdd_midwinter'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., gdd_midwinter, 'gather', nbp_glo, index_g)
    IF (ALL(gdd_midwinter(:,:) == val_exp)) gdd_midwinter(:,:) = undef
    !-
    ncd_dormance(:,:) = val_exp
    var_name = 'ncd_dormance'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., ncd_dormance, 'gather', nbp_glo, index_g)
    IF (ALL(ncd_dormance(:,:) == val_exp)) ncd_dormance(:,:) = undef
    !-
    ngd_minus5(:,:) = val_exp
    var_name = 'ngd_minus5'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., ngd_minus5, 'gather', nbp_glo, index_g)
    IF (ALL(ngd_minus5(:,:) == val_exp)) ngd_minus5(:,:) = zero
    !-
    time_hum_min(:,:) = val_exp
    var_name = 'time_hum_min'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., time_hum_min, 'gather', nbp_glo, index_g)
    IF (ALL(time_hum_min(:,:) == val_exp)) time_hum_min(:,:) = undef
    !-
    hum_min_dormance(:,:) = val_exp
    var_name = 'hum_min_dormance'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., hum_min_dormance, 'gather', nbp_glo, index_g)
    IF (ALL(hum_min_dormance(:,:) == val_exp)) &
         &     hum_min_dormance(:,:) = undef
    !-
    ! 13 Plant status
    !-
    PFTpresent_real(:,:) = val_exp
    var_name = 'PFTpresent'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., PFTpresent_real, 'gather', nbp_glo, index_g)
    IF (ALL(PFTpresent_real(:,:) == val_exp)) PFTpresent_real(:,:) = zero
    WHERE (PFTpresent_real(:,:) >= .5)
       PFTpresent = .TRUE.
    ELSEWHERE
       PFTpresent = .FALSE.
    ENDWHERE
    !-
    ind(:,:) = val_exp
    var_name = 'ind'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., ind, 'gather', nbp_glo, index_g)
    IF (ALL(ind(:,:) == val_exp)) ind(:,:) = zero
    !-
    adapted(:,:) = val_exp
    var_name = 'adapted'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., adapted, 'gather', nbp_glo, index_g)
    IF (ALL(adapted(:,:) == val_exp)) adapted(:,:) = zero
    !-
    regenerate(:,:) = val_exp
    var_name = 'regenerate'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., regenerate, 'gather', nbp_glo, index_g)
    IF (ALL(regenerate(:,:) == val_exp)) regenerate(:,:) = zero
    !-
    npp_longterm(:,:) = val_exp
    var_name = 'npp_longterm'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., npp_longterm, 'gather', nbp_glo, index_g)
    IF (ALL(npp_longterm(:,:) == val_exp)) npp_longterm(:,:) = zero
    !-
    croot_longterm(:,:) = val_exp
    var_name = 'croot_longterm'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., croot_longterm, 'gather', nbp_glo, index_g)
    IF (ALL(croot_longterm(:,:) == val_exp)) croot_longterm(:,:) = zero
    !-
    lm_lastyearmax(:,:) = val_exp
    var_name = 'lm_lastyearmax'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., lm_lastyearmax, 'gather', nbp_glo, index_g)
    IF (ALL(lm_lastyearmax(:,:) == val_exp)) lm_lastyearmax(:,:) = zero
    !-
    lm_thisyearmax(:,:) = val_exp
    var_name = 'lm_thisyearmax'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., lm_thisyearmax, 'gather', nbp_glo, index_g)
    IF (ALL(lm_thisyearmax(:,:) == val_exp)) lm_thisyearmax(:,:) = zero
    !-
    maxfpc_lastyear(:,:) = val_exp
    var_name = 'maxfpc_lastyear'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., maxfpc_lastyear, 'gather', nbp_glo, index_g)
    IF (ALL(maxfpc_lastyear(:,:) == val_exp)) maxfpc_lastyear(:,:) = zero
    !-
    maxfpc_thisyear(:,:) = val_exp
    var_name = 'maxfpc_thisyear'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., maxfpc_thisyear, 'gather', nbp_glo, index_g)
    IF (ALL(maxfpc_thisyear(:,:) == val_exp)) maxfpc_thisyear(:,:) = zero
    !-
    turnover_time(:,:) = val_exp
    var_name = 'turnover_time'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., turnover_time, 'gather', nbp_glo, index_g)
    IF ( ALL( turnover_time(:,:) == val_exp)) turnover_time(:,:) = 100.
    !-
    turnover_longterm(:,:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'turnover_loterm', nbp_glo, nvm, nparts, nelements, itime, &
         &              .TRUE., turnover_longterm, 'gather', nbp_glo, index_g)
    IF (ALL(turnover_longterm == val_exp)) turnover_longterm = zero
    !-
    gpp_week(:,:) = val_exp
    var_name = 'gpp_week'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., gpp_week, 'gather', nbp_glo, index_g)
    IF (ALL(gpp_week(:,:) == val_exp)) gpp_week(:,:) = zero
    !-
    biomass(:,:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'biomass', nbp_glo, nvm, nparts, nelements, itime, &
         &                   .TRUE., biomass, 'gather', nbp_glo, index_g)
    IF (ALL(biomass == val_exp)) biomass = zero
    !-
    resp_maint_part(:,:,:) = val_exp
    var_name = 'maint_resp'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , nparts, itime, &
         &                   .TRUE., resp_maint_part, 'gather', nbp_glo, index_g)
    IF (ALL(resp_maint_part == val_exp)) resp_maint_part(:,:,:) = zero
    !-
    leaf_age(:,:,:) = val_exp
    var_name = 'leaf_age'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , nleafages, itime, &
         &                   .TRUE., leaf_age, 'gather', nbp_glo, index_g)
    IF (ALL(leaf_age == val_exp)) leaf_age(:,:,:) = zero
    !-
    leaf_frac(:,:,:) = val_exp
    var_name = 'leaf_frac'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , nleafages, itime, &
         &                  .TRUE., leaf_frac, 'gather', nbp_glo, index_g)
    IF (ALL(leaf_frac == val_exp)) leaf_frac(:,:,:) = zero
    !-
    senescence_real(:,:) = val_exp
    var_name = 'senescence'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., senescence_real, 'gather', nbp_glo, index_g)
    IF (ALL(senescence_real(:,:) == val_exp)) senescence_real(:,:) = zero
    WHERE ( senescence_real(:,:) >= .5 )
       senescence = .TRUE.
    ELSEWHERE
       senescence = .FALSE.
    ENDWHERE


    ! Read real value for begin_leaves
    CALL restget_p (rest_id_stomate, 'begin_leaves', nbp_glo, nvm  , 1, itime, &
         .TRUE., begin_leaves_real, 'gather', nbp_glo, index_g)
    IF (ALL(begin_leaves_real(:,:) == val_exp)) begin_leaves_real(:,:) = zero

    ! Transform into logical needed by the modele
    WHERE ( begin_leaves_real(:,:) >= 0.5 )
       begin_leaves = .TRUE.
    ELSEWHERE
       begin_leaves = .FALSE.
    ENDWHERE


    when_growthinit(:,:) = val_exp
    var_name = 'when_growthinit'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., when_growthinit, 'gather', nbp_glo, index_g)
    IF (ALL(when_growthinit(:,:) == val_exp)) &
         &     when_growthinit(:,:) = 240.

    !-
    age(:,:) = val_exp
    var_name = 'age'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., age, 'gather', nbp_glo, index_g)
    IF (ALL(age(:,:) == val_exp)) age(:,:) = zero
    !-
    ! 13 CO2
    !-
    resp_hetero(:,:) = val_exp
    var_name = 'resp_hetero'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                .TRUE., resp_hetero, 'gather', nbp_glo, index_g)
    IF (ALL(resp_hetero(:,:) == val_exp)) resp_hetero(:,:) = zero
    !-
    resp_maint(:,:) = val_exp
    var_name = 'resp_maint'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., resp_maint, 'gather', nbp_glo, index_g)
    IF (ALL(resp_maint(:,:) == val_exp)) resp_maint(:,:) = zero
    !-
    resp_growth(:,:) = val_exp
    var_name = 'resp_growth'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., resp_growth, 'gather', nbp_glo, index_g)
    IF (ALL(resp_growth(:,:) == val_exp)) resp_growth(:,:) = zero
    !-
    resp_excess(:,:) = val_exp
    var_name = 'resp_excess'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., resp_excess, 'gather', nbp_glo, index_g)
    IF (ALL(resp_excess(:,:) == val_exp)) resp_excess(:,:) = zero
    !-
    co2_fire(:,:) = val_exp
    var_name = 'co2_fire'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm     , 1, itime, &
         &                .TRUE., co2_fire, 'gather', nbp_glo, index_g)
    IF (ALL(co2_fire(:,:) == val_exp)) co2_fire(:,:) = zero
    !-
    co2_to_bm_dgvm(:,:) = val_exp
    var_name = 'co2_to_bm_dgvm'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm     , 1, itime, &
         &                .TRUE., co2_to_bm_dgvm, 'gather', nbp_glo, index_g)
    IF (ALL(co2_to_bm_dgvm(:,:) == val_exp)) co2_to_bm_dgvm(:,:) = zero

    co2_to_bm_radia(:,:) = val_exp
    var_name = 'co2_to_bm_radia'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm     , 1, itime, &
         &                .TRUE., co2_to_bm_radia, 'gather', nbp_glo, index_g)
    IF (ALL(co2_to_bm_radia(:,:) == val_exp)) co2_to_bm_radia(:,:) = zero
    !-
    n_to_bm(:,:) = val_exp
    var_name = 'n_to_bm'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm     , 1, itime, &
         &                .TRUE., n_to_bm, 'gather', nbp_glo, index_g)
    IF (ALL(n_to_bm(:,:) == val_exp)) n_to_bm(:,:) = zero
    !-
    ! 14 vegetation distribution after last light competition
    !-
    veget_lastlight(:,:) = val_exp
    var_name = 'veget_lastlight'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., veget_lastlight, 'gather', nbp_glo, index_g)
    IF (ALL(veget_lastlight(:,:) == val_exp)) veget_lastlight(:,:) = zero
    !-
    ! 15 establishment criteria
    !-
    everywhere(:,:) = val_exp
    var_name = 'everywhere'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., everywhere, 'gather', nbp_glo, index_g)
    IF (ALL(everywhere(:,:) == val_exp)) everywhere(:,:) = zero
    !-
    need_adjacent_real(:,:) = val_exp
    var_name = 'need_adjacent'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., need_adjacent_real, 'gather', nbp_glo, index_g)
    IF (ALL(need_adjacent_real(:,:) == val_exp)) &
         &     need_adjacent_real(:,:) = zero
    WHERE ( need_adjacent_real(:,:) >= .5 )
       need_adjacent = .TRUE.
    ELSEWHERE
       need_adjacent = .FALSE.
    ENDWHERE
    !-
    RIP_time(:,:) = val_exp
    var_name = 'RIP_time'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., RIP_time, 'gather', nbp_glo, index_g)
    IF (ALL(RIP_time(:,:) == val_exp)) RIP_time(:,:) = large_value
    !-
    ! 17 litter
    !-
    litter(:,:,:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'litter', nbp_glo, nlitt, nvm, nlevs, nelements, itime, &
         &                     .TRUE., litter, 'gather', nbp_glo, index_g)
    IF (ALL(litter == val_exp)) litter = zero



   c_litter_manure(:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'c_litter_manure', nbp_glo, nvm,1, itime, &
         &                     .TRUE., c_litter_manure, 'gather', nbp_glo, index_g)
    IF (ALL(c_litter_manure == val_exp)) c_litter_manure = zero

   m_graz(:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'm_graz', nbp_glo, nlm,forms, itime, &
         &                     .TRUE., m_graz, 'gather', nbp_glo, index_g)
    IF (ALL(m_graz == val_exp)) m_graz = zero

   m_app(:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'm_app', nbp_glo, nlm,forms, itime, &
         &                     .TRUE., m_app, 'gather', nbp_glo, index_g)
    IF (ALL(m_app == val_exp)) m_app = zero

    distr_eff(:,:) = val_exp
     CALL restget_p (rest_id_stomate, 'distr_eff', nbp_glo, nlm,1, itime, &
          &                     .TRUE., distr_eff, 'gather', nbp_glo, index_g)
     IF (ALL(distr_eff == val_exp)) distr_eff = zero

     biomass_N(:,:) = val_exp
      CALL restget_p (rest_id_stomate, 'biomass_N', nbp_glo, nlm,1, itime, &
           &                     .TRUE., biomass_N, 'gather', nbp_glo, index_g)
      IF (ALL(biomass_N == val_exp)) biomass_N = zero

      biomass_cropC_lit(:,:) = val_exp
       CALL restget_p (rest_id_stomate, 'biomass_cropC_lit', nbp_glo, nlm,1, itime, &
            &                     .TRUE., biomass_cropC_lit, 'gather', nbp_glo, index_g)
       IF (ALL(biomass_cropC_lit == val_exp)) biomass_cropC_lit = zero

       biomass_cropN_lit(:,:) = val_exp
        CALL restget_p (rest_id_stomate, 'biomass_cropN_lit', nbp_glo, nlm,1, itime, &
             &                     .TRUE., biomass_cropN_lit, 'gather', nbp_glo, index_g)
        IF (ALL(biomass_cropN_lit == val_exp)) biomass_cropN_lit = zero


      CALL restget_p (rest_id_stomate, 'cn_crop', itime, .TRUE.,val_exp, cn_crop)
      IF (cn_crop == val_exp) THEN
         CALL ipslerr(2, 'stomate_io readstart','cn_crop was not in restart file','', '')
          cn_crop = zero
       END IF


      cn_grass(:) = val_exp
       CALL restget_p (rest_id_stomate, 'cn_grass', nbp_glo, 1,1, itime, &
            &                     .TRUE., cn_grass, 'gather', nbp_glo, index_g)
       IF (ALL(cn_grass == val_exp)) cn_grass = zero

     sum_biomass_th_grass(:) = val_exp
      CALL restget_p (rest_id_stomate, 'sum_biomass_th_grass', nbp_glo, 1,1, itime, &
           &                     .TRUE., sum_biomass_th_grass, 'gather', nbp_glo, index_g)
      IF (ALL(sum_biomass_th_grass == val_exp)) sum_biomass_th_grass = zero

    sum_biomass_th_crop_tot(:) = val_exp
     CALL restget_p (rest_id_stomate, 'sum_biomass_th_crop_tot', nbp_glo, 1,1, itime, &
          &                     .TRUE., sum_biomass_th_crop_tot, 'gather', nbp_glo, index_g)
     IF (ALL(sum_biomass_th_crop_tot == val_exp)) sum_biomass_th_crop_tot = zero

     frac_grass(:,:) = val_exp
      CALL restget_p (rest_id_stomate, 'frac_grass', nbp_glo, nlm,1, itime, &
           &                     .TRUE., frac_grass, 'gather', nbp_glo, index_g)
      IF (ALL(frac_grass == val_exp)) frac_grass = zero

    frac_crop_tot(:,:) = val_exp
     CALL restget_p (rest_id_stomate, 'frac_crop_tot', nbp_glo, nlm,1, itime, &
          &                     .TRUE., frac_crop_tot, 'gather', nbp_glo, index_g)
     IF (ALL(frac_crop_tot == val_exp)) frac_crop_tot = zero

     frac_lit(:,:) = val_exp
      CALL restget_p (rest_id_stomate, 'frac_lit', nbp_glo, nlm,1, itime, &
           &                     .TRUE., frac_lit, 'gather', nbp_glo, index_g)
      IF (ALL(frac_lit == val_exp)) frac_lit = zero

      intake(:,:) = val_exp
       CALL restget_p (rest_id_stomate, 'intake', nbp_glo, nlm,1, itime, &
            &                     .TRUE., intake, 'gather', nbp_glo, index_g)
       IF (ALL(intake == val_exp)) intake = zero

    biomass_th_grass(:,:) = val_exp
     CALL restget_p (rest_id_stomate, 'biomass_th_grass', nbp_glo, nlm,1, itime, &
          &                     .TRUE., biomass_th_grass, 'gather', nbp_glo, index_g)
     IF (ALL(biomass_th_grass == val_exp)) biomass_th_grass = zero

     biomass_th_crop_alim(:,:) = val_exp
      CALL restget_p (rest_id_stomate, 'biomass_th_crop_alim', nbp_glo, nlm,1, itime, &
           &                     .TRUE., biomass_th_crop_alim, 'gather', nbp_glo, index_g)
      IF (ALL(biomass_th_crop_alim == val_exp)) biomass_th_crop_alim = zero

      biomass_th_crop_lit(:,:) = val_exp
       CALL restget_p (rest_id_stomate, 'biomass_th_crop_lit', nbp_glo, nlm,1, itime, &
            &                     .TRUE., biomass_th_crop_lit, 'gather', nbp_glo, index_g)
       IF (ALL(biomass_th_crop_lit == val_exp)) biomass_th_crop_lit = zero

     biomass_eff_grass(:,:) = val_exp
      CALL restget_p (rest_id_stomate, 'biomass_eff_grass', nbp_glo, nlm,1, itime, &
           &                     .TRUE., biomass_eff_grass, 'gather', nbp_glo, index_g)
      IF (ALL(biomass_eff_grass == val_exp)) biomass_eff_grass = zero

      biomass_eff_crop_alim(:,:) = val_exp
       CALL restget_p (rest_id_stomate, 'biomass_eff_crop_alim', nbp_glo, nlm,1, itime, &
            &                     .TRUE., biomass_eff_crop_alim, 'gather', nbp_glo, index_g)
       IF (ALL(biomass_eff_crop_alim == val_exp)) biomass_eff_crop_alim = zero

       biomass_eff_crop_lit(:,:) = val_exp
        CALL restget_p (rest_id_stomate, 'biomass_eff_crop_lit', nbp_glo, nlm,1, itime, &
             &                     .TRUE., biomass_eff_crop_lit, 'gather', nbp_glo, index_g)
        IF (ALL(biomass_eff_crop_lit == val_exp)) biomass_eff_crop_lit = zero

     emis_house_tot(:,:) = val_exp
      CALL restget_p (rest_id_stomate, 'emis_house_tot', nbp_glo, nlm,1, itime, &
           &                     .TRUE., emis_house_tot, 'gather', nbp_glo, index_g)
      IF (ALL(emis_house_tot == val_exp)) emis_house_tot = zero

      emis_yard(:,:) = val_exp
       CALL restget_p (rest_id_stomate, 'emis_yard', nbp_glo, nlm,1, itime, &
            &                     .TRUE., emis_yard, 'gather', nbp_glo, index_g)
       IF (ALL(emis_yard == val_exp)) emis_yard = zero

       emis_sto_tot(:,:) = val_exp
        CALL restget_p (rest_id_stomate, 'emis_sto_tot', nbp_glo, nlm,1, itime, &
             &                     .TRUE., emis_sto_tot, 'gather', nbp_glo, index_g)
        IF (ALL(emis_sto_tot == val_exp)) emis_sto_tot = zero

    !-
    dead_leaves(:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'dead_leaves', nbp_glo, nvm  , nlitt, itime, &
            &                   .TRUE., dead_leaves, 'gather', nbp_glo, index_g)
    IF (ALL(dead_leaves(:,:,:) == val_exp)) dead_leaves = zero

    som(:,:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'carbon', nbp_glo, ncarb, nvm, itime, &
         &                   .TRUE., som(:,:,:,icarbon), 'gather', nbp_glo, index_g)
    IF (ALL(som(:,:,:,icarbon) == val_exp)) THEN
       som(:,iactive,:,icarbon) = 1000.
       som(:,isurface,:,icarbon) = 1000.
       som(:,islow,:,icarbon) = 3000.
       som(:,ipassive,:,icarbon) = 5000.
    ENDIF

    CALL restget_p (rest_id_stomate, 'nitrogen', nbp_glo, ncarb , nvm, itime, &
            &                   .TRUE., som(:,:,:,initrogen), 'gather', nbp_glo, index_g)
    IF (ALL(som(:,:,:,initrogen) == val_exp)) THEN
       som(:,iactive,:,initrogen) = som(:,iactive,:,icarbon) / CN_target_iactive_ref
       som(:,isurface,:,initrogen) = som(:,isurface,:,icarbon) / CN_target_isurface_ref
       som(:,islow,:,initrogen) = som(:,islow,:,icarbon) / CN_target_islow_ref
       som(:,ipassive,:,initrogen) =  som(:,ipassive,:,icarbon) / CN_target_ipassive_ref
    ENDIF
    !-
    lignin_struc(:,:,:) = val_exp
    CALL restget_p &
            &    (rest_id_stomate, 'lignin_struc', nbp_glo, nvm, nlevs, itime, &
            &     .TRUE., lignin_struc, 'gather', nbp_glo, index_g)
    IF (ALL(lignin_struc == val_exp)) lignin_struc = zero

    !-
    lignin_wood(:,:,:) = val_exp
    CALL restget_p &
            &    (rest_id_stomate, 'lignin_wood', nbp_glo, nvm, nlevs, itime, &
            &     .TRUE., lignin_wood, 'gather', nbp_glo, index_g)
    IF (ALL(lignin_wood == val_exp)) lignin_wood = zero
    !-
    ! 18 land cover change
    !-
    ! Read from restart file or set to zero if the variables or restart file were not found

    var_name = 'co2_flux'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         .TRUE., co2_flux, 'gather', nbp_glo, index_g)
    IF (ALL(co2_flux(:,:) == val_exp)) co2_flux(:,:) = zero

    var_name = 'fco2_lu'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         .TRUE., fco2_lu, 'gather', nbp_glo, index_g)
    IF (ALL(fco2_lu(:) == val_exp)) fco2_lu(:) = zero

    var_name = 'fco2_wh'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         .TRUE., fco2_wh, 'gather', nbp_glo, index_g)
    IF (ALL(fco2_wh(:) == val_exp)) fco2_wh(:) = zero

    var_name = 'fco2_ha'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         .TRUE., fco2_ha, 'gather', nbp_glo, index_g)
    IF (ALL(fco2_ha(:) == val_exp)) fco2_ha(:) = zero


    IF (vegetmap_reset) THEN
       ! Reset vegetation map related variables instead of reading from restart file
       prod10(:,:) = zero
       prod100(:,:) = zero
       flux10(:,:) = zero
       flux100(:,:) = zero
       convflux(:) = zero
       cflux_prod10(:) = zero
       cflux_prod100(:) = zero
       convfluxpft(:,:) = zero

    ELSE
       ! Read from restart file or set to zero if the variables or restart file were not found
       prod10(:,:) = val_exp
       var_name = 'prod10'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 11     , 1, itime, &
            .TRUE., prod10, 'gather', nbp_glo, index_g)
       IF (ALL(prod10(:,:) == val_exp)) prod10(:,:) = zero

       prod100(:,:) = val_exp
       var_name = 'prod100'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 101     , 1, itime, &
            .TRUE., prod100, 'gather', nbp_glo, index_g)
       IF (ALL(prod100(:,:) == val_exp)) prod100(:,:) = zero

       flux10(:,:) = val_exp
       var_name = 'flux10'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 10     , 1, itime, &
            .TRUE., flux10, 'gather', nbp_glo, index_g)
       IF (ALL(flux10(:,:) == val_exp)) flux10(:,:) = zero

       flux100(:,:) = val_exp
       var_name = 'flux100'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 100     , 1, itime, &
            .TRUE., flux100, 'gather', nbp_glo, index_g)
       IF (ALL(flux100(:,:) == val_exp)) flux100(:,:) = zero

       convflux(:) = val_exp
       var_name = 'convflux'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
            .TRUE., convflux, 'gather', nbp_glo, index_g)
       IF (ALL(convflux(:) == val_exp)) convflux(:) = zero

       cflux_prod10(:) = val_exp
       var_name = 'cflux_prod10'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
            .TRUE., cflux_prod10, 'gather', nbp_glo, index_g)
       IF (ALL(cflux_prod10(:) == val_exp)) cflux_prod10(:) = zero

       cflux_prod100(:) = val_exp
       var_name = 'cflux_prod100'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
            .TRUE., cflux_prod100, 'gather', nbp_glo, index_g)
       IF (ALL(cflux_prod100(:) == val_exp)) cflux_prod100(:) = zero

       convfluxpft(:,:) = val_exp
       var_name = 'convfluxpft'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
            .TRUE., convfluxpft, 'gather', nbp_glo, index_g)
       IF (ALL(convfluxpft(:,:) == val_exp)) convfluxpft(:,:) = zero
    END IF

    fDeforestToProduct(:,:) = val_exp
    var_name = 'fDeforestToProduct'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &   .TRUE., fDeforestToProduct, 'gather', nbp_glo, index_g)
    IF (ALL(fDeforestToProduct(:,:) ==val_exp)) fDeforestToProduct(:,:) = zero

    fLulccResidue(:,:) = val_exp
    var_name = 'fLulccResidue'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &   .TRUE., fLulccResidue, 'gather', nbp_glo, index_g)
    IF (ALL(fLulccResidue(:,:) ==val_exp)) fLulccResidue(:,:) = zero

    fHarvestToProduct(:,:) = val_exp
    var_name = 'fHarvestToProduct'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &   .TRUE., fHarvestToProduct, 'gather', nbp_glo, index_g)
    IF (ALL(fHarvestToProduct(:,:) ==val_exp)) fHarvestToProduct(:,:) = zero

    !-
    ! 18-bis wood harvest
    !-
    IF (do_wood_harvest) THEN
       prod10_harvest(:,:) = val_exp
       var_name = 'prod10_harvest'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 11     , 1, itime, &
            .TRUE., prod10_harvest, 'gather', nbp_glo, index_g)
       IF (ALL(prod10_harvest(:,:) == val_exp)) prod10_harvest(:,:) = zero

       prod100_harvest(:,:) = val_exp
       var_name = 'prod100_harvest'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 101     , 1, itime, &
            .TRUE., prod100_harvest, 'gather', nbp_glo, index_g)
       IF (ALL(prod100_harvest(:,:) == val_exp)) prod100_harvest(:,:) = zero

       flux10_harvest(:,:) = val_exp
       var_name = 'flux10_harvest'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 10     , 1, itime, &
            .TRUE., flux10_harvest, 'gather', nbp_glo, index_g)
       IF (ALL(flux10_harvest(:,:) == val_exp)) flux10_harvest(:,:) = zero

       flux100_harvest(:,:) = val_exp
       var_name = 'flux100_harvest'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 100     , 1, itime, &
            .TRUE., flux100_harvest, 'gather', nbp_glo, index_g)
       IF (ALL(flux100_harvest(:,:) == val_exp)) flux100_harvest(:,:) = zero

       convflux_harvest(:) = val_exp
       var_name = 'convflux_harvest'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
            .TRUE., convflux_harvest, 'gather', nbp_glo, index_g)
       IF (ALL(convflux_harvest(:) == val_exp)) convflux_harvest(:) = zero

       cflux_prod10_harvest(:) = val_exp
       var_name = 'cflux_prod10_harvest'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
            .TRUE., cflux_prod10_harvest, 'gather', nbp_glo, index_g)
       IF (ALL(cflux_prod10_harvest(:) == val_exp)) cflux_prod10_harvest(:) = zero

       cflux_prod100_harvest(:) = val_exp
       var_name = 'cfluxprod100_harvest'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
            .TRUE., cflux_prod100_harvest, 'gather', nbp_glo, index_g)
       IF (ALL(cflux_prod100_harvest(:) == val_exp)) cflux_prod100_harvest(:) = zero

       woodharvestpft(:,:) = val_exp
       var_name = 'woodharvestpft'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
            .TRUE., woodharvestpft, 'gather', nbp_glo, index_g)
       IF (ALL(woodharvestpft(:,:) == val_exp)) woodharvestpft(:,:) = zero
    END IF


    bm_to_litter(:,:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'bm_to_litter', nbp_glo, nvm, nparts, nelements, itime, &
        &                .TRUE., bm_to_litter, 'gather', nbp_glo, index_g)
    IF (ALL(bm_to_litter == val_exp)) bm_to_litter = zero

    tree_bm_to_litter(:,:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'tree_to_litter', nbp_glo, nvm, nparts, nelements, itime, &
          &                .TRUE., tree_bm_to_litter, 'gather', nbp_glo, index_g)
    IF (ALL(tree_bm_to_litter == val_exp)) tree_bm_to_litter = zero

    carb_mass_total(:) = val_exp
    var_name = 'carb_mass_total'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &              .TRUE., carb_mass_total, 'gather', nbp_glo, index_g)
    IF (ALL(carb_mass_total(:) == val_exp)) carb_mass_total(:) = zero


    IF ( ok_soil_carbon_discretization ) THEN
       CALL restget_p (rest_id_stomate, 'deepSOM_a', nbp_glo, ngrnd, nvm, nelements,  itime, &
          .TRUE., deepSOM_a, 'gather', nbp_glo, index_g)
       IF (ALL(deepSOM_a == val_exp)) THEN
          deepSOM_a(:,:,:,icarbon) = 10.
          deepSOM_a(:,:,:,initrogen) = deepSOM_a(:,:,:,icarbon) / CN_target_iactive_ref
       ENDIF

       CALL restget_p (rest_id_stomate, 'deepSOM_s', nbp_glo, ngrnd, nvm, nelements, itime, &
          .TRUE., deepSOM_s, 'gather', nbp_glo, index_g)
       IF (ALL(deepSOM_s == val_exp)) THEN
          deepSOM_s(:,:,:,icarbon) = 30.
          deepSOM_s(:,:,:,initrogen) = deepSOM_s(:,:,:,icarbon) / CN_target_islow_ref
       ENDIF

       CALL restget_p (rest_id_stomate, 'deepSOM_p', nbp_glo, ngrnd, nvm, nelements, itime, &
          .TRUE., deepSOM_p, 'gather', nbp_glo, index_g)
       IF (ALL(deepSOM_p == val_exp)) THEN
          deepSOM_p(:,:,:,icarbon) = 50.
          deepSOM_p(:,:,:,initrogen) = deepSOM_p(:,:,:,icarbon) / CN_target_ipassive_ref
       ENDIF

       CALL restget_p (rest_id_stomate, 'O2_soil', nbp_glo, ngrnd, nvm, itime, &
            .TRUE., O2_soil, 'gather', nbp_glo, index_g)
       IF (ALL(O2_soil == val_exp)) O2_soil = O2_init_conc

       CALL restget_p (rest_id_stomate,'CH4_soil', nbp_glo, ngrnd, nvm, itime, &
            .TRUE., CH4_soil, 'gather', nbp_glo, index_g)
       IF (ALL(CH4_soil == val_exp)) CH4_soil = CH4_init_conc

       CALL restget_p (rest_id_stomate, 'O2_snow', nbp_glo, nsnow, nvm, itime, &
            .TRUE., O2_snow, 'gather', nbp_glo, index_g)
       IF (ALL(O2_snow == val_exp)) O2_snow = O2_init_conc


       CH4_snow(:,:,:) = val_exp
       CALL restget_p (rest_id_stomate,'CH4_snow', nbp_glo, nsnow, nvm, itime, &
            .TRUE., CH4_snow, 'gather', nbp_glo, index_g)
       IF (ALL(CH4_snow == val_exp)) CH4_snow = CH4_init_conc

       CALL restget_p (rest_id_stomate,'heat_Zimov', nbp_glo, ngrnd, nvm, itime, &
            .TRUE., heat_Zimov, 'gather', nbp_glo, index_g)
       IF (ALL(heat_Zimov == val_exp)) THEN
          heat_Zimov(:,:,:) = 0.0
       ENDIF

       CALL restget_p (rest_id_stomate,'altmax', nbp_glo, nvm, 1, itime, &
            .TRUE., altmax, 'gather', nbp_glo, index_g)
       IF (ALL(altmax(:,:) == val_exp)) THEN
          altmax(:,:) = 0.0
       ENDIF

       CALL restget_p (rest_id_stomate,'depth_organic_soil', nbp_glo, 1, 1, itime, &
           .TRUE., depth_organic_soil(:), 'gather', nbp_glo, index_g)
       IF (ALL(depth_organic_soil(:) == val_exp)) THEN
           depth_organic_soil(:) = 0.0
           read_input_depth_organic_soil = .TRUE.
       ENDIF

       fixed_cryoturbation_depth(:,:) = val_exp
       CALL restget_p (rest_id_stomate,'fixed_cryoturb_depth', nbp_glo, nvm, 1, itime, &
            .TRUE., fixed_cryoturbation_depth, 'gather', nbp_glo, index_g)
       IF (ALL(fixed_cryoturbation_depth(:,:) == val_exp)) THEN
          fixed_cryoturbation_depth(:,:) = 0.0
       ENDIF

    ENDIF


    nflux_prod(:) = val_exp
    var_name = 'nfluxprod'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &              .TRUE., nflux_prod, 'gather', nbp_glo, index_g)
    IF (ALL(nflux_prod(:) == val_exp)) nflux_prod(:) = zero

    nflux_prod_harvest(:) = val_exp
    var_name = 'nfluxprodhar'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
         &              .TRUE., nflux_prod_harvest, 'gather', nbp_glo, index_g)
    IF (ALL(nflux_prod_harvest(:) == val_exp)) nflux_prod_harvest(:) = zero
    !-
    ! 19. Spinup
    !-
    IF (spinup_analytic) THEN

       ! If the variable is not in the restart file, then zero will be used as default value
       CALL restget_p (rest_id_stomate, 'Global_years', itime, .TRUE., zero, global_years)

       nbp_accu(:) = val_exp
       var_name = 'nbp_sum'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
            &              .TRUE., nbp_accu, 'gather', nbp_glo, index_g)
       IF (ALL(nbp_accu(:) == val_exp)) nbp_accu(:) = zero

       nbp_flux(:) = val_exp
       var_name = 'nbp_flux'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo, 1     , 1, itime, &
            &              .TRUE., nbp_flux, 'gather', nbp_glo, index_g)
       IF (ALL(nbp_flux(:) == val_exp)) nbp_flux(:) = zero

       !-
       ok_equilibrium_real(:) = val_exp
       var_name = 'ok_equilibrium'
       CALL restget_p (rest_id_stomate, var_name, nbp_glo , 1  , 1, itime, &
            &                .TRUE., ok_equilibrium_real,'gather', nbp_glo, index_g)
       IF (ALL(ok_equilibrium_real(:) == val_exp)) ok_equilibrium_real(:) = zero
       WHERE(ok_equilibrium_real(:) >= 0.5)
          ok_equilibrium = .TRUE.
       ELSEWHERE
          ok_equilibrium = .FALSE.
       ENDWHERE

       MatrixV(:,:,:,:) = val_exp
       CALL restget_p (rest_id_stomate, 'MatrixV', nbp_glo, nvm, nbpools, nbpools, itime, &
                  &                     .TRUE., MatrixV, 'gather', nbp_glo, index_g)
       ! If nothing is found in the restart file, we initialize each submatrix by identity
       IF (ALL(MatrixV(:,:,:,:) == val_exp))  THEN
          MatrixV(:,:,:,:) = zero
          DO l = 1,nbpools
             MatrixV(:,:,l,l) = un
          END DO
       END IF

       VectorU(:,:,:)  = val_exp
       CALL restget_p &
            &    (rest_id_stomate, 'Vector_U', nbp_glo, nvm, nbpools, itime, &
            &     .TRUE., VectorU, 'gather', nbp_glo, index_g)
       IF (ALL(VectorU == val_exp))  VectorU = zero

       previous_stock(:,:,:)  = val_exp
       CALL restget_p &
            &    (rest_id_stomate, 'previous_stock', nbp_glo, nvm, nbpools, itime, &
            &     .TRUE., previous_stock, 'gather', nbp_glo, index_g)
       IF (ALL(previous_stock == val_exp))  previous_stock = undef_sechiba

       current_stock(:,:,:)  = val_exp
       CALL restget_p &
            &    (rest_id_stomate, 'current_stock', nbp_glo, nvm, nbpools, itime, &
            &     .TRUE., current_stock, 'gather', nbp_glo, index_g)
       IF (ALL(current_stock == val_exp))  current_stock = zero

       CN_som_litter_longterm(:,:,:)  = val_exp
       CALL restget_p &
            &    (rest_id_stomate, 'CN_longterm', nbp_glo, nvm, nbpools, itime, &
            &     .TRUE., CN_som_litter_longterm, 'gather', nbp_glo, index_g)
       IF (ALL(CN_som_litter_longterm == val_exp))  CN_som_litter_longterm = zero

       ! If the variable is not in the restart file, then dt_sechiba/one_day will be used as default value
       CALL restget_p(rest_id_stomate, 'tau_CN_longterm', itime, .TRUE., dt_sechiba/one_day, tau_CN_longterm)

    ENDIF ! spinup_matrix_method

    KF(:,:) = val_exp
    var_name = 'KF'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., KF, 'gather', nbp_glo, index_g)
    ! I don't want to set it equal to zero, since this is a problem if these
    ! values are not here!  Better it blows up later on
    !IF (ALL(KF(:,:) == val_exp)) KF(:,:) = zero

    k_latosa_adapt(:,:) = val_exp
    var_name = 'k_latosa_adapt'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                .TRUE., k_latosa_adapt, 'gather', nbp_glo, index_g)
    DO m = 1,nvm
       IF (ALL(k_latosa_adapt(:,m) == val_exp)) k_latosa_adapt(:,m) = k_latosa_min(m)
    ENDDO

    rue_longterm(:,:) = val_exp
    var_name = 'rue_longterm'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm , 1, itime, &
         &        .TRUE., rue_longterm(:,:), 'gather', nbp_glo, index_g)
    IF (ALL(rue_longterm(:,:) == val_exp)) rue_longterm(:,:) = 1.

    cn_leaf_min_season(:,:) = val_exp
    var_name = 'cn_leaf_min_season'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., cn_leaf_min_season, 'gather', nbp_glo, index_g)
    IF ( ALL(cn_leaf_min_season(:,:) == val_exp) ) THEN
       DO m=1,nvm
          cn_leaf_min_season(:,m) = cn_leaf_init_2D(:,m)
       ENDDO
    ENDIF

    nstress_season(:,:) = val_exp
    var_name = 'nstress_season'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., nstress_season, 'gather', nbp_glo, index_g)
    IF ( ALL(nstress_season(:,:) == val_exp) ) nstress_season(:,:)=1.0

    soil_n_min(:,:,:) = val_exp
    CALL restget_p (rest_id_stomate, 'soil_n_min', nbp_glo, nvm, nnspec, itime, &
         &              .TRUE., soil_n_min, 'gather', nbp_glo, index_g)
!    IF ( ALL(soil_n_min(:,:,k) == val_exp) ) soil_n_min(:,:,k)=100000000.
    IF ( ALL(soil_n_min == val_exp) ) soil_n_min=0.

    p_O2(:,:) = val_exp
    var_name = 'p_O2'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., p_O2(:,:), 'gather', nbp_glo, index_g)
    IF ( ALL(p_O2(:,:) == val_exp) ) p_O2(:,:)=200

    bact(:,:) = val_exp
    var_name = 'bact'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              .TRUE., bact(:,:), 'gather', nbp_glo, index_g)
    IF ( ALL(bact(:,:) == val_exp) ) bact(:,:)=10


    ! Read assim_param from restart file. The initialization of assim_param will
    ! be done in stomate_var_init if the variable is not in the restart file.
    assim_param(:,:,:)  = val_exp
    CALL restget_p &
         &    (rest_id_stomate, 'assim_param', nbp_glo, nvm, npco2, itime, &
         &     .TRUE., assim_param, 'gather', nbp_glo, index_g)


    CALL restget_p (rest_id_stomate, 'harvest_above', nbp_glo, nelements  , 1, itime, &
         .TRUE., harvest_above(:,:), 'gather', nbp_glo, index_g)
    IF ( ALL(harvest_above(:,:) == val_exp) ) harvest_above(:,:) = 0.

    sugar_load(:,:) = val_exp
    var_name = 'sugar_load'
    CALL restget_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &   .TRUE., sugar_load, 'gather', nbp_glo, index_g)
    IF (ALL(sugar_load(:,:) ==val_exp)) sugar_load(:,:) = un

    IF (printlev >= 4) WRITE(numout,*) 'Leaving readstart'
    !-----------------------
  END SUBROUTINE readstart

!! ================================================================================================================================
!! SUBROUTINE   : writerestart
!!
!>\BRIEF        Write all variables for stomate from restart file.
!!
!! DESCRIPTION  : Write all variables for stomate from restart file.
!!
!! \n
!_ ================================================================================================================================

  SUBROUTINE writerestart &
       & (npts, index, dt_days, date_loc, &
       &  ind, adapted, regenerate, moiavail_daily, gdd_init_date, litterhum_daily, &
       &  t2m_daily, t2m_min_daily, tsurf_daily, tsoil_daily, &
       &  soilhum_daily, precip_daily, bm_alloc_daily, gi ,graz_above_daily, gpp_daily, npp_daily, &
       &  turnover_daily, moiavail_month, moiavail_week, moiavail_growingseason,&
       &  t2m_longterm, tau_longterm, t2m_month, t2m_week, &
       &  tsoil_month, soilhum_month, fireindex, firelitter, &
       &  maxmoiavail_lastyear, maxmoiavail_thisyear, &
       &  minmoiavail_lastyear, minmoiavail_thisyear, &
       &  maxgppweek_lastyear, maxgppweek_thisyear, &
       &  gdd0_lastyear, gdd0_thisyear, precip_lastyear, precip_thisyear, &
       &  bm_alloc_lastyear, bm_alloc_thisyear, &
       &  graz_above_lastyear, graz_above_thisyear, &
       &  harvest_above_lastyear, harvest_above_thisyear, &
       &  gdd_m5_dormance, gdd_from_growthinit, gdd_midwinter, ncd_dormance, ngd_minus5, &
       &  PFTpresent, npp_longterm, croot_longterm, lm_lastyearmax, lm_thisyearmax, &
       &  maxfpc_lastyear, maxfpc_thisyear, &
       &  turnover_longterm, gpp_week, biomass, resp_maint_part, &
       &  leaf_age, leaf_frac, senescence, when_growthinit, age, &
       &  resp_hetero, resp_maint, resp_growth,resp_excess, co2_fire, co2_to_bm_dgvm, co2_to_bm_radia, &
       &  n_to_bm, veget_lastlight, everywhere, need_adjacent, RIP_time, &
       &  time_hum_min, hum_min_dormance, &
       &  litter,c_litter_manure,m_graz, m_app, distr_eff, biomass_N, biomass_cropC_lit, &
       &   biomass_cropN_lit,sum_biomass_th_grass, sum_biomass_th_crop_tot, &
       &  frac_grass,frac_crop_tot, frac_lit, intake, biomass_th_grass, biomass_th_crop_alim, biomass_th_crop_lit, &
       &  biomass_eff_grass, biomass_eff_crop_alim, biomass_eff_crop_lit, &
       &   cn_crop, cn_grass,emis_house_tot, emis_yard, emis_sto_tot, dead_leaves, &
       &  som, lignin_struc, lignin_wood, turnover_time, &
       &  co2_flux, fco2_lu, fco2_wh, fco2_ha,  &
       &  prod10,prod100 ,flux10, flux100, &
       &  convflux, cflux_prod10, cflux_prod100, &
       &  prod10_harvest,prod100_harvest ,flux10_harvest, flux100_harvest, &
       &  convflux_harvest, cflux_prod10_harvest, cflux_prod100_harvest, &
       &  convfluxpft, fDeforestToProduct, fLulccResidue, fHarvestToProduct, &
       &  woodharvestpft, bm_to_litter, tree_bm_to_litter, carb_mass_total, nflux_prod, &
       &  nflux_prod_harvest, Tseason, Tseason_length, Tseason_tmp, &
       &  Tmin_spring_time, begin_leaves, onset_date, &
       &  global_years, ok_equilibrium, nbp_accu, nbp_flux, &
       &  MatrixV, VectorU, previous_stock, current_stock, assim_param, &
       &  CN_som_litter_longterm, tau_CN_longterm, KF, k_latosa_adapt, &
       &  rue_longterm, cn_leaf_min_season, nstress_season, soil_n_min, p_O2, bact, &
       &  deepSOM_a, deepSOM_s, deepSOM_p, O2_soil, CH4_soil, O2_snow, CH4_snow, &
       &  heat_Zimov, altmax, depth_organic_soil, fixed_cryoturbation_depth, harvest_above, sugar_load)

    !---------------------------------------------------------------------
    !- write restart file
    !---------------------------------------------------------------------
    !-
    ! 0 declarations
    !-
    ! 0.1 input
    !-
    ! Domain size
    INTEGER(i_std),INTENT(in) :: npts
    ! Indices of the points on the map
    INTEGER(i_std),DIMENSION(npts),INTENT(in) :: index
    ! time step of STOMATE in days
    REAL(r_std),INTENT(in) :: dt_days
    ! date_loc (d)
    INTEGER(i_std),INTENT(in) :: date_loc
    ! density of individuals (1/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: ind
    ! Winter too cold? between 0 and 1
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: adapted
    ! Winter sufficiently cold? between 0 and 1
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: regenerate
    ! daily moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: moiavail_daily
    ! gdd init date
    REAL(r_std),DIMENSION(npts,2),INTENT(in) :: gdd_init_date
    ! daily litter humidity
    REAL(r_std),DIMENSION(npts),INTENT(in) :: litterhum_daily
    ! daily 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(in) :: t2m_daily
    ! daily minimum 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(in) :: t2m_min_daily
    ! daily surface temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(in) :: tsurf_daily
    ! daily soil temperatures (K)
    REAL(r_std),DIMENSION(npts,nslm),INTENT(in) :: tsoil_daily
    ! daily soil humidity
    REAL(r_std),DIMENSION(npts,nslm),INTENT(in) :: soilhum_daily
    ! daily precipitations (mm/day) (for phenology)
    REAL(r_std),DIMENSION(npts),INTENT(in) :: precip_daily
    ! daily gross primary productivity (gC/m**2/day)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: gpp_daily
    ! daily net primary productivity (gC/m**2/day)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: npp_daily
    ! daily net primary productivity  (gC/m**2/day)
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(in) :: bm_alloc_daily
    ! grazing intensity
    REAL(r_std),DIMENSION(npts),INTENT(in) :: gi
    ! daily biomass grazed
    REAL(r_std),DIMENSION(npts,nelements),INTENT(in) :: graz_above_daily
    ! daily turnover rates (gC/m**2/day)
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(in) :: turnover_daily
    ! "monthly" moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: moiavail_month
    ! "weekly" moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: moiavail_week
    ! mean growing season moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: moiavail_growingseason
    ! "long term" 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(in) :: t2m_longterm
    ! "tau_longterm"
    REAL(r_std), INTENT(IN)             :: tau_longterm
    ! "monthly" 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(in) :: t2m_month
    ! "seasonal" 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(in)      :: Tseason
    ! temporary variable to calculate Tseason
    REAL(r_std),DIMENSION(npts),INTENT(in)      :: Tseason_length
    ! temporary variable to calculate Tseason
    REAL(r_std),DIMENSION(npts),INTENT(in)      :: Tseason_tmp
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in)  :: Tmin_spring_time
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in)  :: onset_date
    LOGICAL,DIMENSION(npts,nvm),INTENT(in)      :: begin_leaves

    ! "weekly" 2 meter temperatures (K)
    REAL(r_std),DIMENSION(npts),INTENT(in) :: t2m_week
    ! "monthly" soil temperatures (K)
    REAL(r_std),DIMENSION(npts,nslm),INTENT(in) :: tsoil_month
    ! "monthly" soil humidity
    REAL(r_std),DIMENSION(npts,nslm),INTENT(in) :: soilhum_month
    ! Probability of fire
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: fireindex
    ! Longer term total litter above the ground, gC/m**2 of ground
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: firelitter
    ! last year's maximum moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: maxmoiavail_lastyear
    ! this year's maximum moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: maxmoiavail_thisyear
    ! last year's minimum moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: minmoiavail_lastyear
    ! this year's minimum moisture availability
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: minmoiavail_thisyear
    ! last year's maximum weekly GPP
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: maxgppweek_lastyear
    ! this year's maximum weekly GPP
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: maxgppweek_thisyear
    ! last year's annual GDD0
    REAL(r_std),DIMENSION(npts),INTENT(in) :: gdd0_lastyear
    ! this year's annual GDD0
    REAL(r_std),DIMENSION(npts),INTENT(in) :: gdd0_thisyear
    ! last year's annual precipitation (mm/year)
    REAL(r_std),DIMENSION(npts),INTENT(in) :: precip_lastyear
    ! this year's annual precipitation (mm/year)
    REAL(r_std),DIMENSION(npts),INTENT(in) :: precip_thisyear
    ! last year's annual npp
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(in) :: bm_alloc_lastyear
    ! this year's annual npp
    REAL(r_std),DIMENSION(npts,nvm,nparts, nelements),INTENT(in) :: bm_alloc_thisyear
    ! last year's annual biomass grazed
    REAL(r_std),DIMENSION(npts,nelements),INTENT(in) :: graz_above_lastyear
    ! this year's annual biomass grazed
    REAL(r_std),DIMENSION(npts,nelements),INTENT(in) :: graz_above_thisyear
    ! last year's annual biomass harvested
    REAL(r_std),DIMENSION(npts,nelements),INTENT(in) :: harvest_above_lastyear
    ! this year's annual biomass harvested
    REAL(r_std),DIMENSION(npts,nelements),INTENT(in) :: harvest_above_thisyear
    ! growing degree days, threshold -5 deg C (for phenology)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: gdd_m5_dormance
    ! growing degree days, from begin of season (crops)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: gdd_from_growthinit
    ! growing degree days since midwinter (for phenology)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: gdd_midwinter
    ! number of chilling days since leaves were lost (for phenology)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: ncd_dormance
    ! number of growing days, threshold -5 deg C (for phenology)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: ngd_minus5
    ! PFT exists (equivalent to fpc_max > 0 for natural PFTs)
    LOGICAL,DIMENSION(npts,nvm),INTENT(in) :: PFTpresent
    ! "long term" net primary productivity (gC/m**2/year)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: npp_longterm
    ! "long term" root carbon mass (gC/m**2/year)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: croot_longterm
    ! last year's maximum leaf mass, for each PFT (gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: lm_lastyearmax
    ! this year's maximum leaf mass, for each PFT (gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: lm_thisyearmax
    ! last year's maximum fpc for each natural PFT, on ground
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: maxfpc_lastyear
    ! this year's maximum fpc for each PFT,
    ! on *total* ground (see stomate_season)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: maxfpc_thisyear
    ! "long term" turnover rate (gC/m**2/year)
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(in) :: turnover_longterm
    ! "weekly" GPP (gC/day/(m**2 covered)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: gpp_week
    ! biomass (gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(in) :: biomass
    ! maintenance respiration (gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm,nparts),INTENT(in) :: resp_maint_part
    ! leaf age (days)
    REAL(r_std),DIMENSION(npts,nvm,nleafages),INTENT(in) :: leaf_age
    ! fraction of leaves in leaf age class
    REAL(r_std),DIMENSION(npts,nvm,nleafages),INTENT(in) :: leaf_frac
    ! is the plant senescent ?
    ! (only for deciduous trees - carbohydrate reserve)
    LOGICAL,DIMENSION(npts,nvm),INTENT(in) :: senescence
    ! how many days ago was the beginning of the growing season
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: when_growthinit
    ! mean age (years)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: age
    ! heterotrophic respiration (gC/day/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: resp_hetero
    ! maintenance respiration (gC/day/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: resp_maint
    ! growth respiration (gC/day/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: resp_growth
    ! excess respiration (gC/day/m**2)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: resp_excess
    ! carbon emitted into the atmosphere by fire (living and dead biomass)
    ! (in gC/m**2/time step)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: co2_fire
    ! biomass uptaken (gC/(m**2 of total ground)/day)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: co2_to_bm_dgvm
    ! biomass uptaken (gN/(m**2 of total ground)/day)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: n_to_bm
    ! biomass uptaken (gC/(m**2 of total ground)/dt_sechiba)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: co2_to_bm_radia
    ! vegetation fractions (on ground) after last light competition
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: veget_lastlight
    ! is the PFT everywhere in the grid box or very localized
    ! (after its introduction)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: everywhere
    ! in order for this PFT to be introduced,
    ! does it have to be present in an adjacent grid box?
    LOGICAL,DIMENSION(npts,nvm),INTENT(in) :: need_adjacent
    ! How much time ago was the PFT eliminated for the last time (y)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: RIP_time
    ! time elapsed since strongest moisture availability (d)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: time_hum_min
    ! minimum moisture during dormance
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: hum_min_dormance
    ! fraction of litter above the ground belonging to different PFTs
    REAL(r_std),DIMENSION(npts,nlitt,nvm,nlevs,nelements),INTENT(in) :: litter
    ! dead leaves on ground, per PFT, metabolic and structural,
    ! in gC/(m**2 of ground)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) ::c_litter_manure
    ! ! Carbon manure returned in the soil as litter
    REAL(r_std),DIMENSION(npts,nlm,forms),INTENT(in) ::m_graz
    ! ! Manure deposited during grazing period in days
    REAL(r_std),DIMENSION(npts,nlm,forms),INTENT(in) ::m_app
    ! ! Manure deposited during application period
    REAL(r_std), DIMENSION(npts,nlm), INTENT(in):: distr_eff           !! Livestock distribution map reajusted according to actual biomass grazed
                                                                                        !! (Heads/km2/yr)
  REAL(r_std), DIMENSION(npts,nlm), INTENT(in)            :: biomass_N        !! Biomass ingested by each animal (kg N/m2/yr)
  REAL(r_std), DIMENSION(npts,nlm), INTENT(in)            :: biomass_cropC_lit !! Biomass used as litter by each animal (kg C/m2/yr)
  REAL(r_std), DIMENSION(npts,nlm), INTENT(in)            :: biomass_cropN_lit !! Biomass used as litter by each animal (kg N/m2/yr)


  REAL(r_std), INTENT(in)          :: cn_crop            ! CN of the crop biomass
  REAL(r_std), DIMENSION(npts), INTENT(in)         :: cn_grass            ! CN of the grass biomass
  REAL(r_std), DIMENSION(npts), INTENT(in)          :: sum_biomass_th_grass !! Sum of the estimated grass biomass ingested by all the animals
                                                                              !! kg C/m2/yr
  REAL(r_std), DIMENSION(npts), INTENT(in)          :: sum_biomass_th_crop_tot !! Sum of the estimated crop biomass ingested by all the animals
                                                                              !! kg C/m2/yr
  REAL(r_std),DIMENSION(npts,nlm), INTENT(in)        :: frac_grass         !! Proportion of importance of each animal in grass biomass
  REAL(r_std),DIMENSION(npts,nlm), INTENT(in)        :: frac_crop_tot      !! Proportion of importance of each animal in crop biomass
  REAL(r_std),DIMENSION(npts,nlm), INTENT(in)        :: frac_lit           !! Proportion of importance of each animal in crop biomass used as litter
  REAL(r_std), DIMENSION(npts,nlm), INTENT(in)       :: intake           !! Intake required for each animal (kg C/year/ani)
  REAL(r_std), DIMENSION(npts,nlm), INTENT(in)        :: biomass_th_grass  !! Carbon biomass from grass estimated for each animal
                                                                            !! kg C/m2/yr
   REAL(r_std), DIMENSION(npts,nlm), INTENT(in)        :: biomass_th_crop_alim !! Feed crop biomass required for each animal (kg C/m2/yr)
   REAL(r_std), DIMENSION(npts,nlm), INTENT(in)        :: biomass_th_crop_lit !! Theoretical crop biomass used as litter by each animal (kg C/m2/yr)
   REAL(r_std),DIMENSION(npts,nlm),INTENT(in)          :: biomass_eff_grass    !! Actual grass biomass used by each animal (kg C/m2/yr)
   REAL(r_std),DIMENSION(npts,nlm),INTENT(in)      :: biomass_eff_crop_alim ! Actual crop biomass ingested by each animal (kg C/m2/yr)
   REAL(r_std),DIMENSION(npts,nlm),INTENT(in)      :: biomass_eff_crop_lit  !! Actual crop biomass used as litter by each animal (kg C/m2/yr)
    REAL(r_std), DIMENSION(npts,nlm), INTENT(in):: emis_house_tot     !! NH3 Emissions from manure at housing (liquid + solid)
                                                                                  !! for each animal (kg TAN/m2/yr)
    REAL(r_std), DIMENSION(npts,nlm), INTENT(in):: emis_yard         !! NH3 Emissions from manure at yard (liquid + solid)
                                                                                  !! for each animal (kg TAN/m2/yr)
    REAL(r_std), DIMENSION(npts,nlm), INTENT(in):: emis_sto_tot      !! NH3 Emissions from manure during storage (liquid + solid)
                                                                                  !! for each animal (kg TAN/m2/yr)
    REAL(r_std),DIMENSION(npts,nvm,nlitt),INTENT(in) :: dead_leaves
    ! SOM pool: active, slow, or passive, (gC(orN)/m**2)
    REAL(r_std),DIMENSION(npts,ncarb,nvm,nelements),INTENT(in) :: som
   ! ratio Lignine/Carbon in structural litter, above and below ground, (gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm,nlevs),INTENT(in) :: lignin_struc
    ! turnover_time of leaves
    ! ratio Lignine/Carbon in woody litter, above and below ground, (gC/m**2)
    REAL(r_std),DIMENSION(npts,nvm,nlevs),INTENT(in) :: lignin_wood
    ! turnover_time of leaves
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in) :: turnover_time
    REAL(r_std), DIMENSION(npts,nelements), INTENT(in)          :: harvest_above
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)                :: sugar_load  !! Relative sugar loading of the labile pool (unitless)

    ! For Spinup matrix resolution
    INTEGER(i_std), INTENT(in) :: global_years
    LOGICAL, DIMENSION(npts), INTENT(in) :: ok_equilibrium
    REAL(r_std), DIMENSION(npts), INTENT(in) :: nbp_accu  !! Accumulated Net Biospheric Production over the year
    REAL(r_std), DIMENSION(npts), INTENT(in) :: nbp_flux  !! Net Biospheric Production over the year
    !-
    REAL(r_std), DIMENSION(npts,nvm,nbpools,nbpools), INTENT(in) :: MatrixV
    REAL(r_std), DIMENSION(npts,nvm,nbpools), INTENT(in) :: VectorU
    REAL(r_std), DIMENSION(npts,nvm,nbpools), INTENT(in) :: previous_stock
    REAL(r_std), DIMENSION(npts,nvm,nbpools), INTENT(in) :: current_stock
    REAL(r_std), DIMENSION(npts,nvm,nbpools), INTENT(in) :: CN_som_litter_longterm !! Longterm CN ratio of litter and som pools (gC/gN)
    REAL(r_std), INTENT(in)                              :: tau_CN_longterm  !! Counter used for calculating the longterm CN ratio of SOM and litter pools (seconds)
    REAL(r_std), DIMENSION(npts,nvm,npco2),   INTENT(in) :: assim_param
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)         :: KF                !! Scaling factor to convert sapwood mass
                                                                              !! into leaf mass (m)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)         :: k_latosa_adapt    !! Leaf to sapwood area adapted for water
                                                                              !! stress. Adaptation takes place at the
                                                                              !! end of the year (m)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)         :: rue_longterm      !! Longterm radiation use efficiency

    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)         :: cn_leaf_min_season    !! Seasonal CN ratio of leaves
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)         :: nstress_season    !! N-related seasonal stress (used for allocation)

    REAL(r_std), DIMENSION(npts,nvm,nnspec), INTENT(in)  :: soil_n_min        !! mineral nitrogen in the soil (gN/m**2)
                                                                              !! (first index=npts, second index=nvm, third index=nnspec)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)        :: p_O2               !! partial pressure of oxigen in the soil (hPa)
                                                                              !! (first index=npts, second index=nvm)

    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)        :: bact               !! denitrifier biomass (gC/m**2)
                                                                                                   !! (first index=npts, second index=nvm)

    ! Variables related to ok_soil_carbon_discretization
    REAL(r_std), DIMENSION(npts,ngrnd,nvm,nelements),INTENT(in) :: deepSOM_a
    REAL(r_std), DIMENSION(npts,ngrnd,nvm,nelements),INTENT(in) :: deepSOM_s
    REAL(r_std), DIMENSION(npts,ngrnd,nvm,nelements),INTENT(in) :: deepSOM_p
    REAL(r_std), DIMENSION(npts,ngrnd,nvm),INTENT(in)           :: O2_soil
    REAL(r_std), DIMENSION(npts,ngrnd,nvm),INTENT(in)           :: CH4_soil
    REAL(r_std), DIMENSION(npts,nsnow,nvm),INTENT(in)           :: O2_snow
    REAL(r_std), DIMENSION(npts,nsnow,nvm),INTENT(in)           :: CH4_snow
    REAL(r_std), DIMENSION(npts,ngrnd,nvm), INTENT(in)          :: heat_Zimov
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)                :: altmax
    REAL(r_std), DIMENSION(npts),INTENT(in)                     :: depth_organic_soil
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)                :: fixed_cryoturbation_depth

    !-
    ! 0.2 local
    !-
    ! date, real
    REAL(r_std) :: date_real
    ! PFT exists (equivalent to fpc_max > 0 for natural PFTs), real
    REAL(r_std),DIMENSION(npts,nvm) :: PFTpresent_real
    ! is the plant senescent ?
    ! (only for deciduous trees - carbohydrate reserve), real
    REAL(r_std),DIMENSION(npts,nvm) :: senescence_real
    REAL(r_std),DIMENSION(npts,nvm) :: begin_leaves_real

    ! in order for this PFT to be introduced,
    ! does it have to be present in an adjacent grid box? - real
    REAL(r_std),DIMENSION(npts,nvm) :: need_adjacent_real
    ! To store variables names for I/O
    CHARACTER(LEN=80) :: var_name
    ! string suffix indicating an index
    CHARACTER(LEN=10) :: part_str
    ! string suffix indicating litter type
    CHARACTER(LEN=4),DIMENSION(nlitt) :: litter_str
    ! string suffix indicating level
    CHARACTER(LEN=2),DIMENSION(nlevs) :: level_str
    ! temporary storage
    REAL(r_std),DIMENSION(1) :: xtmp
    ! index
    INTEGER(i_std) :: j,k,l,m
    CHARACTER(LEN=2),DIMENSION(nelements) :: element_str  !! string suffix indicating element
    REAL(r_std), DIMENSION(1) :: temp_global_years
    CHARACTER(LEN=6),DIMENSION(nbpools) :: pools_str
    REAL(r_std), DIMENSION(npts) :: ok_equilibrium_real

    ! land cover change variables
    ! products remaining in the 10/100 year-turnover pool after the annual release for each compartment
    ! (10 or 100 + 1 : input from year of land cover change)
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in)                            :: co2_flux
    REAL(r_std),DIMENSION(npts),INTENT(in)                                :: fco2_lu
    REAL(r_std),DIMENSION(npts),INTENT(in)                                :: fco2_wh
    REAL(r_std),DIMENSION(npts),INTENT(in)                                :: fco2_ha
    REAL(r_std),DIMENSION(npts,0:10),INTENT(in)                           :: prod10
    REAL(r_std),DIMENSION(npts,0:100),INTENT(in)                          :: prod100
    ! annual release from the 10/100 year-turnover pool compartments
    REAL(r_std),DIMENSION(npts,10),INTENT(in)                           :: flux10
    REAL(r_std),DIMENSION(npts,100),INTENT(in)                          :: flux100
    REAL(r_std), DIMENSION(npts), INTENT(in)                            :: convflux
    REAL(r_std), DIMENSION(npts), INTENT(in)                            :: cflux_prod10
    REAL(r_std), DIMENSION(npts), INTENT(in)                            :: cflux_prod100

    ! wood harvest variables
    ! products remaining in the 10/100 year-turnover pool after the annual release for each compartment
    ! (10 or 100 + 1 : input from year of land cover change)
    REAL(r_std),DIMENSION(npts,0:10),INTENT(in)                           :: prod10_harvest
    REAL(r_std),DIMENSION(npts,0:100),INTENT(in)                          :: prod100_harvest
    ! annual release from the 10/100 year-turnover pool compartments
    REAL(r_std),DIMENSION(npts,10),INTENT(in)                           :: flux10_harvest
    REAL(r_std),DIMENSION(npts,100),INTENT(in)                          :: flux100_harvest
    REAL(r_std), DIMENSION(npts), INTENT(in)                            :: convflux_harvest
    REAL(r_std), DIMENSION(npts), INTENT(in)                            :: cflux_prod10_harvest
    REAL(r_std), DIMENSION(npts), INTENT(in)                            :: cflux_prod100_harvest
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)                        :: convfluxpft
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)                        :: fDeforestToProduct
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)                        :: fLulccResidue
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)                        :: fHarvestToProduct
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)                        :: woodharvestpft
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(in)         :: bm_to_litter
    REAL(r_std),DIMENSION(npts,nvm,nparts,nelements),INTENT(in)         :: tree_bm_to_litter
    REAL(r_std),DIMENSION(npts),INTENT(in)                              :: carb_mass_total
    REAL(r_std), DIMENSION(npts), INTENT(in)                            :: nflux_prod
    REAL(r_std), DIMENSION(npts), INTENT(in)                            :: nflux_prod_harvest
    !---------------------------------------------------------------------
    IF (printlev >= 3) WRITE(numout,*) 'Entering writerestart'
    !-
    ! 1 string definitions
    !-
    DO l=1,nlitt
       IF     (l == imetabolic) THEN
          litter_str(l) = 'met'
       ELSEIF (l == istructural) THEN
          litter_str(l) = 'str'
       ELSEIF (l == iwoody) THEN
          litter_str(l) = 'wood'
       ELSE
          CALL ipslerr_p(3,'stomate_io writerestart','Define litter_str','','')
       ENDIF
    ENDDO
    !-
    DO l=1,nlevs
       IF     (l == iabove) THEN
          level_str(l) = 'ab'
       ELSEIF (l == ibelow) THEN
          level_str(l) = 'be'
       ELSE
          CALL ipslerr_p(3,'stomate_io writerestart','Define level_str','','')
       ENDIF
    ENDDO
    !-
    DO l=1,nelements
       IF     (l == icarbon) THEN
          element_str(l) = ''
       ELSEIF (l == initrogen) THEN
          element_str(l) = '_n'
       ELSE
          CALL ipslerr_p(3,'stomate_io writerestart','Define element_str','','')
       ENDIF
    ENDDO
    !-
    pools_str(1:nbpools) =(/'str_ab ','str_be ','met_ab ','met_be ','wood_ab','wood_be', &
         & 'actif  ','slow   ','passif ','surface'/)

    !-
    IF (is_root_prc) THEN
       CALL ioconf_setatt_p ('UNITS','-')
       CALL ioconf_setatt_p ('LONG_NAME',' ')
    ENDIF
    !-
    ! 2 run control
    !-
    ! 2.2 time step of STOMATE in days
    !-
    CALL restput_p (rest_id_stomate, 'dt_days', itime, dt_days)
    !-
    ! 2.3 date
    !-
    CALL restput_p (rest_id_stomate, 'date', itime, date_loc)
    !-
    ! 3 daily meteorological variables
    !-
    var_name = 'moiavail_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                moiavail_daily, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'gdd_init_date'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo,    2, 1, itime, &
         &              gdd_init_date, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'litterhum_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo,    1, 1, itime, &
         &                litterhum_daily, 'scatter', nbp_glo, index_g)
    !-
    var_name = 't2m_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo,    1, 1, itime, &
         &                t2m_daily, 'scatter', nbp_glo, index_g)
    !-
    var_name = 't2m_min_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo,    1, 1, itime, &
         &                t2m_min_daily, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'tsurf_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo,    1, 1, itime, &
         &                tsurf_daily, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'tsoil_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nslm, 1, itime, &
         &                tsoil_daily, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'soilhum_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nslm, 1, itime, &
         &                soilhum_daily, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'precip_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo,    1, 1, itime, &
         &                precip_daily, 'scatter', nbp_glo, index_g)
    !-
    ! 4 productivities
    !-
    var_name = 'gpp_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                gpp_daily, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'npp_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                npp_daily, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'bm_alloc_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, nparts, nelements, itime, &
      &                bm_alloc_daily, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'gi'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1,1, itime, &
      &                gi, 'scatter', nbp_glo, index_g)

    var_name = 'graz_above_daily'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nelements,1, itime, &
      &                graz_above_daily, 'scatter', nbp_glo, index_g)
    !-


    CALL restput_p (rest_id_stomate, 'turnover_daily', nbp_glo, nvm, nparts, nelements, itime, &
         &                   turnover_daily, 'scatter', nbp_glo, index_g)
    !-
    ! 5 monthly meteorological variables
    !-
    var_name = 'moiavail_month'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                moiavail_month, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'moiavail_week'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                moiavail_week, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'moiavail_grow'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                moiavail_growingseason, 'scatter', nbp_glo, index_g)
    !-
    var_name = 't2m_longterm'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo,    1, 1, itime, &
         &                t2m_longterm, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'tau_longterm', itime, tau_longterm)


    var_name = 't2m_month'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo,    1, 1, itime, &
                         t2m_month, 'scatter', nbp_glo, index_g)


    CALL restput_p (rest_id_stomate, 'Tseason', nbp_glo,    1, 1, itime, &
         Tseason, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'Tseason_length', nbp_glo,    1, 1, itime, &
         Tseason_length, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'Tseason_tmp', nbp_glo,    1, 1, itime, &
         Tseason_tmp, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'Tmin_spring_time', nbp_glo, nvm, 1, itime, &
         Tmin_spring_time, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'onset_date', nbp_glo, nvm, 1, itime, &
         onset_date(:,:), 'scatter', nbp_glo, index_g)

    var_name = 't2m_week'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo,    1, 1, itime, &
         &                t2m_week, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'tsoil_month'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nslm, 1, itime, &
         &                tsoil_month, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'soilhum_month'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nslm, 1, itime, &
         &                soilhum_month, 'scatter', nbp_glo, index_g)
    !-
    ! 6 fire probability
    !-
    var_name = 'fireindex'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                fireindex, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'firelitter'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                firelitter, 'scatter', nbp_glo, index_g)
    !-
    ! 7 maximum and minimum moisture availabilities for tropic phenology
    !-
    var_name = 'maxmoistr_last'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                maxmoiavail_lastyear, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'maxmoistr_this'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                maxmoiavail_thisyear, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'minmoistr_last'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                minmoiavail_lastyear, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'minmoistr_this'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                minmoiavail_thisyear, 'scatter', nbp_glo, index_g)
    !-
    ! 8 maximum "weekly" GPP
    !-
    var_name = 'maxgppweek_lastyear'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                maxgppweek_lastyear, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'maxgppweek_thisyear'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                maxgppweek_thisyear, 'scatter', nbp_glo, index_g)
    !-
    ! 9 annual GDD0
    !-
    var_name = 'gdd0_thisyear'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &                gdd0_thisyear, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'gdd0_lastyear'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &                gdd0_lastyear, 'scatter', nbp_glo, index_g)
    !-
    ! 10 annual precipitation
    !-
    var_name = 'precip_thisyear'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &                precip_thisyear, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'precip_lastyear'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &                precip_lastyear, 'scatter', nbp_glo, index_g)

   !-
   ! 11 annual npp
   !-
   var_name = 'bm_alloc_thisyear'
   CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, nparts, nelements, itime, &
        &                bm_alloc_thisyear, 'scatter', nbp_glo, index_g)
   !-
   var_name = 'bm_alloc_lastyear'
   CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, nparts, nelements, itime, &
        &                bm_alloc_lastyear, 'scatter', nbp_glo, index_g)

  ! 11 bis annual biomass grazed by ruminants
  !-
  var_name = 'graz_above_thisyear'
  CALL restput_p (rest_id_stomate, var_name, nbp_glo, nelements,1, itime, &
       &                graz_above_thisyear, 'scatter', nbp_glo, index_g)
  !-
  var_name = 'graz_above_lastyear'
  CALL restput_p (rest_id_stomate, var_name, nbp_glo, nelements,1, itime, &
       &                graz_above_lastyear, 'scatter', nbp_glo, index_g)

   ! 11 ter annual biomass harvested by ruminants
   !-
   var_name = 'harvest_above_thisyear'
   CALL restput_p (rest_id_stomate, var_name, nbp_glo, nelements,1, itime, &
        &                harvest_above_thisyear, 'scatter', nbp_glo, index_g)
   !-
   var_name = 'harvest_above_lastyear'
   CALL restput_p (rest_id_stomate, var_name, nbp_glo, nelements,1, itime, &
        &                harvest_above_lastyear, 'scatter', nbp_glo, index_g)
    !-
    ! 12 derived "biometeorological" variables
    !-
    var_name = 'gdd_m5_dormance'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                gdd_m5_dormance, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'gdd_from_growthinit'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &              gdd_from_growthinit, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'gdd_midwinter'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                gdd_midwinter, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'ncd_dormance'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                ncd_dormance, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'ngd_minus5'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                ngd_minus5, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'time_hum_min'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                time_hum_min, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'hum_min_dormance'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                hum_min_dormance, 'scatter', nbp_glo, index_g)
    !-
    ! 13 Plant status
    !-
    var_name = 'PFTpresent'
    WHERE ( PFTpresent(:,:) )
       PFTpresent_real = un
    ELSEWHERE
       PFTpresent_real = zero
    ENDWHERE
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                PFTpresent_real, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'ind'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                ind, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'turnover_time'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                turnover_time, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'adapted'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                adapted, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'regenerate'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                regenerate, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'npp_longterm'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                npp_longterm, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'croot_longterm'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                croot_longterm, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'lm_lastyearmax'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                lm_lastyearmax, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'lm_thisyearmax'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                lm_thisyearmax, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'maxfpc_lastyear'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                maxfpc_lastyear, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'maxfpc_thisyear'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                maxfpc_thisyear, 'scatter', nbp_glo, index_g)
    !-
    CALL restput_p (rest_id_stomate, 'turnover_loterm', nbp_glo, nvm, nparts, nelements, itime, &
         &                   turnover_longterm, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'gpp_week'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                gpp_week, 'scatter', nbp_glo, index_g)
    !-
    CALL restput_p (rest_id_stomate, 'biomass', nbp_glo, nvm, nparts, nelements, itime, &
         &                   biomass, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'maint_resp'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, nparts, itime, &
         &                   resp_maint_part, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'leaf_age'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, nleafages, itime, &
         &                  leaf_age, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'leaf_frac'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, nleafages, itime, &
         &                   leaf_frac, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'senescence'
    WHERE ( senescence(:,:) )
       senescence_real = un
    ELSEWHERE
       senescence_real = zero
    ENDWHERE
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                senescence_real, 'scatter', nbp_glo, index_g)

    ! Transform the logical variable begin_leaves to real before writing to restart file
    WHERE ( begin_leaves(:,:) )
       begin_leaves_real = un
    ELSEWHERE
       begin_leaves_real = zero
    ENDWHERE
    CALL restput_p (rest_id_stomate, 'begin_leaves', nbp_glo, nvm, 1, itime, &
         begin_leaves_real, 'scatter', nbp_glo, index_g)


    var_name = 'when_growthinit'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                when_growthinit, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'age'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &                age, 'scatter', nbp_glo, index_g)
    !-
    ! 14 CO2
    !-
    var_name = 'resp_hetero'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                resp_hetero, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'resp_maint'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                resp_maint, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'resp_growth'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                resp_growth, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'resp_excess'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                resp_excess, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'co2_fire'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo,  nvm, 1, itime, &
         &                co2_fire, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'co2_to_bm_dgvm'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                co2_to_bm_dgvm, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'n_to_bm'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                n_to_bm, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'co2_to_bm_radia'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                co2_to_bm_radia, 'scatter', nbp_glo, index_g)
    !-
    ! 15 vegetation distribution after last light competition
    !-
    var_name = 'veget_lastlight'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                veget_lastlight, 'scatter', nbp_glo, index_g)
    !-
    ! 16 establishment criteria
    !-
    var_name = 'everywhere'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                everywhere, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'need_adjacent'
    WHERE (need_adjacent(:,:))
       need_adjacent_real = un
    ELSEWHERE
       need_adjacent_real = zero
    ENDWHERE
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                need_adjacent_real, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'RIP_time'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                RIP_time, 'scatter', nbp_glo, index_g)
    !-
    ! 17 litter
    !-
    CALL restput_p (rest_id_stomate, 'litter', nbp_glo, nlitt, nvm, nlevs, nelements, itime, &
         &                     litter, 'scatter', nbp_glo, index_g)
   CALL restput_p (rest_id_stomate, 'c_litter_manure', nbp_glo, nvm,1, itime, &
         &                     c_litter_manure, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'm_graz', nbp_glo, nlm,forms, itime, &
         &                     m_graz, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'm_app', nbp_glo, nlm,forms, itime, &
         &                     m_app, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'distr_eff', nbp_glo, nlm,1, itime, &
               &                     distr_eff, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'biomass_N', nbp_glo, nlm,1, itime, &
               &                     biomass_N, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'biomass_cropC_lit', nbp_glo, nlm,1, itime, &
               &                     biomass_cropC_lit, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'biomass_cropN_lit', nbp_glo, nlm,1, itime, &
               &                     biomass_cropN_lit, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'cn_crop', itime, cn_crop)

   CALL restput_p (rest_id_stomate, 'cn_grass', nbp_glo, 1,1, itime, &
               &                     cn_grass, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'sum_biomass_th_grass', nbp_glo, 1,1, itime, &
               &                     sum_biomass_th_grass, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'sum_biomass_th_crop_tot', nbp_glo, 1,1, itime, &
               &                     sum_biomass_th_crop_tot, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'frac_grass', nbp_glo, nlm,1, itime, &
              &                     frac_grass, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'frac_crop_tot', nbp_glo, nlm,1, itime, &
                    &                     frac_crop_tot, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'frac_lit', nbp_glo, nlm,1, itime, &
                          &                  frac_lit, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'intake', nbp_glo, nlm,1, itime, &
                           &                  intake, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'biomass_th_grass', nbp_glo, nlm,1, itime, &
               &                     biomass_th_grass, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'biomass_th_crop_alim', nbp_glo, nlm,1, itime, &
                     &                     biomass_th_crop_alim, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'biomass_th_crop_lit', nbp_glo, nlm,1, itime, &
                           &                  biomass_th_crop_lit, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'biomass_eff_grass', nbp_glo, nlm,1, itime, &
              &                     biomass_eff_grass, 'scatter', nbp_glo, index_g)

  CALL restput_p (rest_id_stomate, 'biomass_eff_crop_alim', nbp_glo, nlm,1, itime, &
                    &                     biomass_eff_crop_alim, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'biomass_eff_crop_lit', nbp_glo, nlm,1, itime, &
                          &                  biomass_eff_crop_lit, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'emis_house_tot', nbp_glo, nlm,1, itime, &
               &                     emis_house_tot, 'scatter', nbp_glo, index_g)

   CALL restput_p (rest_id_stomate, 'emis_yard', nbp_glo, nlm,1, itime, &
                     &                     emis_yard, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'emis_sto_tot', nbp_glo, nlm,1, itime, &
                           &                  emis_sto_tot, 'scatter', nbp_glo, index_g)
    !-
    CALL restput_p (rest_id_stomate, 'dead_leaves', nbp_glo,  nvm, nlitt, itime, &
        &                   dead_leaves, 'scatter', nbp_glo, index_g)
    !-
    CALL restput_p (rest_id_stomate, 'carbon', nbp_glo, ncarb, nvm, itime, &
         &                   som(:,:,:,icarbon), 'scatter', nbp_glo, index_g)
    !-
    CALL restput_p (rest_id_stomate, 'nitrogen', nbp_glo, ncarb, nvm, itime, &
         &                   som(:,:,:,initrogen), 'scatter', nbp_glo, index_g)
    !-
    CALL restput_p &
         &      (rest_id_stomate, 'lignin_struc', nbp_glo, nvm, nlevs, itime, &
         &       lignin_struc, 'scatter', nbp_glo, index_g)
    !-
    CALL restput_p &
         &      (rest_id_stomate, 'lignin_wood', nbp_glo, nvm, nlevs, itime, &
         &       lignin_wood, 'scatter', nbp_glo, index_g)
    !-
    ! 18 land cover change
    !-
    var_name = 'co2_flux'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &                co2_flux, 'scatter', nbp_glo, index_g)
    var_name = 'fco2_lu'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &                fco2_lu, 'scatter', nbp_glo, index_g)
    var_name = 'fco2_wh'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &                fco2_wh, 'scatter', nbp_glo, index_g)
    var_name = 'fco2_ha'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &                fco2_ha, 'scatter', nbp_glo, index_g)

    var_name = 'prod10'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 11, 1, itime, &
         &                prod10, 'scatter', nbp_glo, index_g)
    var_name = 'prod100'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 101, 1, itime, &
         &                prod100, 'scatter', nbp_glo, index_g)
    var_name = 'flux10'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 10, 1, itime, &
         &                flux10, 'scatter', nbp_glo, index_g)
    var_name = 'flux100'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 100, 1, itime, &
         &                flux100, 'scatter', nbp_glo, index_g)

    var_name = 'convflux'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &              convflux, 'scatter', nbp_glo, index_g)
    var_name = 'cflux_prod10'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &              cflux_prod10, 'scatter', nbp_glo, index_g)
    var_name = 'cflux_prod100'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &              cflux_prod100, 'scatter', nbp_glo, index_g)
    var_name = 'nfluxprod'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &              nflux_prod, 'scatter', nbp_glo, index_g)

    var_name = 'nfluxprodhar'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
         &              nflux_prod_harvest, 'scatter', nbp_glo, index_g)

    var_name = 'convfluxpft'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              convfluxpft, 'scatter', nbp_glo, index_g)

    var_name = 'fDeforestToProduct'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              fDeforestToProduct, 'scatter', nbp_glo, index_g)

    var_name = 'fLulccResidue'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              fLulccResidue, 'scatter', nbp_glo, index_g)

    var_name = 'fHarvestToProduct'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm  , 1, itime, &
         &              fHarvestToProduct, 'scatter', nbp_glo, index_g)

    !-
    ! 18-bis wood harvest
    !-
    IF (do_wood_harvest) THEN
       var_name = 'prod10_harvest'
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, 11, 1, itime, &
            prod10_harvest, 'scatter', nbp_glo, index_g)
       var_name = 'prod100_harvest'
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, 101, 1, itime, &
            prod100_harvest, 'scatter', nbp_glo, index_g)
       var_name = 'flux10_harvest'
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, 10, 1, itime, &
            flux10_harvest, 'scatter', nbp_glo, index_g)
       var_name = 'flux100_harvest'
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, 100, 1, itime, &
            flux100_harvest, 'scatter', nbp_glo, index_g)
       var_name = 'convflux_harvest'
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
            convflux_harvest, 'scatter', nbp_glo, index_g)
       var_name = 'cflux_prod10_harvest'
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
            cflux_prod10_harvest, 'scatter', nbp_glo, index_g)
       var_name = 'cfluxprod100_harvest'
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
            cflux_prod100_harvest, 'scatter', nbp_glo, index_g)
       var_name = 'woodharvestpft'
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
            woodharvestpft, 'scatter', nbp_glo, index_g)
    END IF

    CALL restput_p (rest_id_stomate, 'bm_to_litter', nbp_glo, nvm, nparts, nelements, itime, &
          &                bm_to_litter, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'tree_to_litter', nbp_glo, nvm, nparts, nelements, itime, &
          &                tree_bm_to_litter, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'carb_mass_total', nbp_glo, 1, 1, itime, &
         &              carb_mass_total, 'scatter', nbp_glo, index_g)

    IF ( ok_soil_carbon_discretization ) THEN
       CALL restput_p (rest_id_stomate, 'deepSOM_a', nbp_glo, ngrnd, nvm, nelements, itime, &
            deepSOM_a, 'scatter', nbp_glo, index_g)

       CALL restput_p (rest_id_stomate, 'deepSOM_s', nbp_glo, ngrnd, nvm, nelements, itime, &
            deepSOM_s, 'scatter', nbp_glo, index_g)

       CALL restput_p (rest_id_stomate, 'deepSOM_p', nbp_glo, ngrnd, nvm, nelements, itime, &
            deepSOM_p, 'scatter', nbp_glo, index_g)

       CALL restput_p (rest_id_stomate, 'O2_soil', nbp_glo, ngrnd, nvm, itime, &
            O2_soil, 'scatter', nbp_glo, index_g)
       CALL restput_p (rest_id_stomate, 'CH4_soil', nbp_glo, ngrnd, nvm, itime, &
            CH4_soil, 'scatter', nbp_glo, index_g)
       CALL restput_p (rest_id_stomate, 'O2_snow', nbp_glo, nsnow, nvm, itime, &
            O2_snow, 'scatter', nbp_glo, index_g)
       CALL restput_p (rest_id_stomate, 'CH4_snow', nbp_glo, nsnow, nvm, itime, &
            CH4_snow, 'scatter', nbp_glo, index_g)

       CALL restput_p (rest_id_stomate, 'heat_Zimov', nbp_glo, ngrnd, nvm, itime, &
            heat_Zimov, 'scatter', nbp_glo, index_g)
       CALL restput_p (rest_id_stomate, 'altmax', nbp_glo, nvm, 1, itime, &
            altmax, 'scatter', nbp_glo, index_g)
       CALL restput_p (rest_id_stomate, 'depth_organic_soil', nbp_glo, 1, 1, itime, &
                      depth_organic_soil, 'scatter', nbp_glo, index_g)

       !Isa dbg : fixed_cryoturbation_depth -> fixed_cryoturb_depth
       var_name = 'fixed_cryoturb_depth'
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
            fixed_cryoturbation_depth, 'scatter', nbp_glo, index_g)
    ENDIF
    !-
    ! 19. Spinup
    !-
    IF (spinup_analytic) THEN

       CALL restput_p (rest_id_stomate, 'Global_years', itime, global_years)

       var_name = 'nbp_sum'
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
            &              nbp_accu, 'scatter', nbp_glo, index_g)

       var_name = 'nbp_flux'
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
            &              nbp_flux, 'scatter', nbp_glo, index_g)

       var_name = 'ok_equilibrium'
       WHERE(ok_equilibrium(:))
          ok_equilibrium_real = un
       ELSEWHERE
          ok_equilibrium_real = zero
       ENDWHERE
       CALL restput_p (rest_id_stomate, var_name, nbp_glo, 1, 1, itime, &
            &               ok_equilibrium_real, 'scatter', nbp_glo, index_g)

       CALL restput_p (rest_id_stomate, 'MatrixV', nbp_glo, nvm, nbpools, nbpools, itime, &
            &                MatrixV, 'scatter', nbp_glo, index_g)

       CALL restput_p (rest_id_stomate, 'Vector_U', nbp_glo, nvm, nbpools, itime, &
            &                VectorU, 'scatter', nbp_glo, index_g)

       CALL restput_p (rest_id_stomate, 'previous_stock', nbp_glo, nvm, nbpools, itime, &
            &                previous_stock, 'scatter', nbp_glo, index_g)

       CALL restput_p (rest_id_stomate, 'current_stock', nbp_glo, nvm, nbpools, itime, &
            &                current_stock, 'scatter', nbp_glo, index_g)

       CALL restput_p (rest_id_stomate, 'CN_longterm', nbp_glo, nvm, nbpools, itime, &
            &                CN_som_litter_longterm, 'scatter', nbp_glo, index_g)

       CALL restput_p (rest_id_stomate, 'tau_CN_longterm', itime, tau_CN_longterm)

    ENDIF !(spinup_analytic)

    !-
    var_name = 'KF'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
          &              KF(:,:), 'scatter', nbp_glo, index_g)
    !-
    var_name = 'k_latosa_adapt'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
          &              k_latosa_adapt(:,:), 'scatter', nbp_glo, index_g)
    !-

    var_name = 'rue_longterm'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
          &              rue_longterm(:,:), 'scatter', nbp_glo, index_g)
    !-
!!$    var_name = 'lai_target'
!!$    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
!!$          &              lai_target(:,:), 'scatter', nbp_glo, index_g)
    !-


    var_name = 'cn_leaf_min_season'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &              cn_leaf_min_season(:,:), 'scatter', nbp_glo, index_g)
    !-
    var_name = 'nstress_season'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &              nstress_season(:,:), 'scatter', nbp_glo, index_g)
    !-
    CALL restput_p (rest_id_stomate, 'soil_n_min', nbp_glo, nvm, nnspec, itime, &
         &              soil_n_min, 'scatter', nbp_glo, index_g)
    !-
    var_name = 'p_O2'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &              p_O2(:,:), 'scatter', nbp_glo, index_g)
    !-
    !-
    var_name = 'bact'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm, 1, itime, &
         &              bact(:,:), 'scatter', nbp_glo, index_g)
    !-
    !-
    CALL restput_p (rest_id_stomate, 'assim_param', nbp_glo, nvm, npco2, itime, &
        &                assim_param, 'scatter', nbp_glo, index_g)

    CALL restput_p (rest_id_stomate, 'harvest_above', nbp_glo, nelements, 1, itime, &
         harvest_above(:,:), 'scatter', nbp_glo, index_g)

    var_name = 'sugar_load'
    CALL restput_p (rest_id_stomate, var_name, nbp_glo, nvm , 1, itime, &
         &              sugar_load, 'scatter', nbp_glo, index_g)

    IF (printlev >= 4) WRITE(numout,*) 'Leaving writerestart'
    !--------------------------
  END SUBROUTINE writerestart
  !-
  !===
  !-
END MODULE stomate_io
